@@ -35,11 +35,20 @@
 #' p2 <- plot_ly(economics, x = ~date, y = ~unemploy)
 #' subplot(p1, p2, p1, p2, nrows = 2, margin = 0.05)
 #' 
+#' #'  # anchor multiple traces on the same legend entry
+#'  p1 <- add_lines(p1, color = I("black"), name = "1st", legendgroup = "1st")
+#'  p2 <- add_lines(p2, color = I("red"), name = "2nd", legendgroup = "2nd")
+#'  
+#'  subplot(
+#'    p1, style(p1, showlegend = FALSE),
+#'    p2, style(p2, showlegend = FALSE),
+#'    nrows = 2, margin = 0.05
+#'  )
+#' 
 #' # or pass a list
-#' library(purrr)
 #' economics_long %>%
 #'   split(.$variable) %>%
-#'   map(~ plot_ly(., x = ~date, y = ~value)) %>%
+#'   lapply(function(d) plot_ly(d, x = ~date, y = ~value)) %>%
 #'   subplot(nrows = NROW(.), shareX = TRUE)
 #'   
 #' # or pass a tibble with a list-column of plotly objects
@@ -54,29 +63,25 @@
 subplot <- function(..., nrows = 1, widths = NULL, heights = NULL, margin = 0.02, 
                     shareX = FALSE, shareY = FALSE, titleX = shareX, 
                     titleY = shareY, which_layout = "merge") {
-  dotz <- list(...)
   
-  if (length(dotz) == 1 && is.list(dotz[[1]]) && !is.plotly(dotz[[1]])) {
-    # if ... is a list (or a tibble), list(...) is a (length 1) list 
-    # containing a list of plotly objects
-    dotz <- dotz[[1]]
-  }
   
-  if (tibble::is_tibble(dotz)) {
-    # if dots is a tibble, search for one column with a list of plotly objects
-    idx <- which(vapply(dotz, function(x) is.plotly(x[[1]]), logical(1)))
-    if (length(idx) != 1) {
-      stop(
-        "If you supply a tibble to subplot(), \n", 
-        "it must have _one_ column with a list of plotly objects",
+  plots <- dots2plots(...)
+  
+  # some plotly functions call plotly_build()...subplot() doesn't like that
+  for (i in seq_along(plots)) {
+    if (!is.null(plots[[i]][["frames"]])) {
+      warning(
+        sprintf("`subplot()` detected plot #%s was 'pre-built' and already has registered\n", i),
+        "animation frames. This can cause problems and may happen by calling a \n", 
+        "function like `animation_opts()` or `highlight()` (which returns a 'built' plot)\n",
+        "_before_ `subplot()`. Consider using such functions _after_ `subplot()`.",
         call. = FALSE
       )
     }
-    dotz <- dotz[[idx]]
   }
   
-  # build each plot
-  plotz <- lapply(dotz, function(d) plotly_build(d)[["x"]])
+  # build all the plots without registering frames
+  plotz <- lapply(plots, function(d) plotly_build(d, registerFrames = FALSE)[["x"]])
   
   # Are any traces referencing "axislike" layout attributes that are missing?
   # If so, move those traces to a "new plot", and inherit layout attributes,
@@ -86,8 +91,8 @@ subplot <- function(..., nrows = 1, widths = NULL, heights = NULL, margin = 0.02
   for (i in seq_along(plotz)) {
     p <- plots[[i]] <- plotz[[i]]
     layoutAttrs <- c(names(p$layout), c("mapbox", "geo", "xaxis", "yaxis"))
-    xTraceAttrs <- sub("^x", "xaxis", sapply(p$data, function(tr) tr[["subplot"]] %||% tr[["geo"]] %||% tr[["xaxis"]]))
-    yTraceAttrs <- sub("^y", "yaxis", sapply(p$data, function(tr) tr[["subplot"]] %||% tr[["geo"]] %||% tr[["yaxis"]]))
+    xTraceAttrs <- sub("^x", "xaxis", sapply(p$data, function(tr) tr[["subplot"]] %||% tr[["geo"]] %||% tr[["xaxis"]] %||% "x"))
+    yTraceAttrs <- sub("^y", "yaxis", sapply(p$data, function(tr) tr[["subplot"]] %||% tr[["geo"]] %||% tr[["yaxis"]] %||% "y"))
     missingAttrs <- setdiff(c(xTraceAttrs, yTraceAttrs), layoutAttrs)
     # move to next iteration if trace references are complete
     if (!length(missingAttrs)) next
@@ -115,6 +120,7 @@ subplot <- function(..., nrows = 1, widths = NULL, heights = NULL, margin = 0.02
   traces <- lapply(plots, "[[", "data")
   layouts <- lapply(plots, "[[", "layout")
   shapes <- lapply(layouts, "[[", "shapes")
+  images <- lapply(layouts, "[[", "images")
   annotations <- lapply(layouts, function(x) {
     # keep non axis title annotations (for rescaling)
     axes <- vapply(x$annotations, function(a) identical(a$annotationType, "axis"), logical(1))
@@ -201,15 +207,34 @@ subplot <- function(..., nrows = 1, widths = NULL, heights = NULL, margin = 0.02
       map <- xMap[xMap %in% sub("x", "xaxis", yAxes[[i]][[j]]$anchor %||% "x")]
       yAxes[[i]][[j]]$anchor <- sub("axis", "", names(map))
     }
-    # map trace xaxis/yaxis/geo attributes
+    
     for (key in c("geo", "subplot", "xaxis", "yaxis")) {
+      # bump trace axis references
       oldAnchors <- unlist(lapply(traces[[i]], "[[", key))
       if (!length(oldAnchors)) next
       axisMap <- if (key == "yaxis") yMap else xMap
       axisMap <- setNames(sub("axis", "", axisMap), sub("axis", "", names(axisMap)))
       newAnchors <- names(axisMap)[match(oldAnchors, axisMap)]
       traces[[i]] <- Map(function(tr, a) { tr[[key]] <- a; tr }, traces[[i]], newAnchors)
+      
+      # bump annotation, image, shape xref/yref
+      # (none of these layout components have geo/subplot support)
+      ref <- list(xaxis = "xref", yaxis = "yref")[[key]]
+      if (is.null(ref)) next
+      bump_axis_ref <- function(obj, ref_default = sub("ref", "", ref)) {
+        # TODO: throw error/warning if ref_default doesn't match axisMap?
+        obj[[ref]] <- obj[[ref]] %||% ref_default
+        if (identical(obj[[ref]], "paper")) return(obj)
+        refIdx <- match(obj[[ref]], axisMap)
+        if (!is.na(refIdx)) obj[[ref]] <- names(axisMap)[refIdx][1]
+        obj
+      }
+      annotations[[i]] <- lapply(annotations[[i]], bump_axis_ref)
+      shapes[[i]] <- lapply(shapes[[i]], bump_axis_ref)
+      images[[i]] <- lapply(images[[i]], bump_axis_ref, "paper")
     }
+    
+    
     # rescale domains according to the tabular layout
     xDom <- as.numeric(domainInfo[i, c("xstart", "xend")])
     yDom <- as.numeric(domainInfo[i, c("yend", "ystart")])
@@ -239,22 +264,23 @@ subplot <- function(..., nrows = 1, widths = NULL, heights = NULL, margin = 0.02
       ax
     })
   }
-  # start merging the plots into a single subplot
+  
   p <- list(
     data = Reduce(c, traces),
     layout = Reduce(modify_list, c(xAxes, rev(yAxes)))
   )
-  # retrain default coloring
-  p$data <- retrain_color_defaults(p$data)
+  
   
   # reposition shapes and annotations
   annotations <- Map(reposition, annotations, split(domainInfo, seq_along(plots)))
   shapes <- Map(reposition, shapes, split(domainInfo, seq_along(plots)))
+  images <- Map(reposition, images, split(domainInfo, seq_along(plots)))
   p$layout$annotations <- Reduce(c, annotations)
   p$layout$shapes <- Reduce(c, shapes)
+  p$layout$images <- Reduce(c, images)
   # merge non-axis layout stuff
   layouts <- lapply(layouts, function(x) {
-    x[!grepl("^[x-y]axis|^geo|^mapbox|annotations|shapes", names(x))] %||% list()
+    x[!grepl("^[x-y]axis|^geo|^mapbox|annotations|shapes|images", names(x))] %||% list()
   })
   if (which_layout != "merge") {
     if (!is.numeric(which_layout)) warning("which_layout must be numeric")
@@ -264,17 +290,64 @@ subplot <- function(..., nrows = 1, widths = NULL, heights = NULL, margin = 0.02
     }
     layouts <- layouts[which_layout]
   }
-  p$layout <- c(p$layout, Reduce(modify_list, layouts))
-  sources <- unique(unlist(lapply(plots, "[[", "source")))
-  if (length(sources) > 1) {
-    stop("Can have multiple source values in a single subplot")
-  }
-  p$config <- Reduce(modify_list, lapply(plots, "[[", "config")) %||% NULL
-  p$source <- sources[1]
+  p$attrs <- Reduce(c, lapply(plots, "[[", "attrs"))
+  p$layout <- modify_list(p$layout, Reduce(modify_list, layouts))
+  p$source <- ensure_one(plots, "source")
+  p$config <- ensure_one(plots, "config")
+  p$highlight <- ensure_one(plots, "highlight")
+  
+  # retrain default coloring
+  p$data <- colorway_retrain(p$data, p$layout$colorway %||% colorway())
+  
   p$subplot <- TRUE
   as_widget(p)
 }
 
+# ----------------------------------------------------------------
+# Functions used solely within subplot()
+# ----------------------------------------------------------------
+
+# take a "collection" of plots and 
+dots2plots <- function(...) {
+  dotz <- list(...)
+  
+  # if ... is a list (or a tibble), list(...) is a (length 1) list 
+  # containing a list of plotly objects
+  if (length(dotz) == 1 && is.list(dotz[[1]]) && !is.plotly(dotz[[1]])) {
+    dotz <- dotz[[1]]
+  }
+  
+  if (tibble::is_tibble(dotz)) {
+    # if dots is a tibble, search for one column with a list of plotly objects
+    idx <- which(vapply(dotz, function(x) is.plotly(x[[1]]), logical(1)))
+    if (length(idx) != 1) {
+      stop(
+        "If you supply a tibble to subplot(), \n", 
+        "it must have _one_ column with a list of plotly objects",
+        call. = FALSE
+      )
+    }
+    dotz <- dotz[[idx]]
+  }
+  
+  dotz
+}
+
+
+
+# helper function that warns if more than one plot-level attribute 
+# has been specified in a list of plots (and returning that attribute)
+ensure_one <- function(plots, attr) {
+  attrs <- lapply(plots, "[", attr)
+  for (i in seq_along(attrs)) {
+    if (!identical(attrs[[1]], attrs[[i]])) {
+      warning("Can only have one: ", attr, call. = FALSE)
+      break
+    }
+  }
+  attrs[[length(attrs)]][[1]]
+}
+
 
 get_domains <- function(nplots = 1, nrows = 1, margins = 0.01, 
                         widths = NULL, heights = NULL) {
@@ -336,22 +409,27 @@ list2df <- function(x, nms) {
 # (useful mostly for repositioning annotations/shapes in subplots)
 reposition <- function(obj, domains) {
   # we need x and y in order to rescale them!
+  xdom <- as.numeric(domains[c("xstart", "xend")])
+  ydom <- as.numeric(domains[c("yend", "ystart")])
+  
   for (i in seq_along(obj)) {
     o <- obj[[i]]
-    # TODO: this implementation currently assumes xref/yref == "paper"
-    # should we support references to axis objects as well?
-    for (j in c("x", "x0", "x1")) {
+    xs <- if (identical(o$xref, "paper")) {
+      if (is.numeric(o$sizex)) obj[[i]]$sizex <- o$sizex * abs(diff(xdom))
+      if (identical(o$xsizemode, "pixel")) "xanchor" else c("x", "x0", "x1")
+    }
+    for (j in xs) {
       if (is.numeric(o[[j]])) {
-        obj[[i]][[j]] <- scales::rescale(
-          o[[j]], as.numeric(domains[c("xstart", "xend")]), from = c(0, 1)
-        )
+        obj[[i]][[j]] <- scales::rescale(o[[j]], xdom, from = c(0, 1))
       }
     }
-    for (j in c("y", "y0", "y1")) {
+    ys <- if (identical(o$yref, "paper")) {
+      if (is.numeric(o$sizey)) obj[[i]]$sizey <- o$sizey * abs(diff(ydom))
+      if (identical(o$ysizemode, "pixel")) "yanchor" else c("y", "y0", "y1")
+    }
+    for (j in ys) {
       if (is.numeric(o[[j]])) {
-        obj[[i]][[j]] <- scales::rescale(
-          o[[j]], as.numeric(domains[c("yend", "ystart")]), from = c(0, 1)
-        )
+        obj[[i]][[j]] <- scales::rescale(o[[j]], ydom, from = c(0, 1))
       }
     }
   }
@@ -359,20 +437,19 @@ reposition <- function(obj, domains) {
 }
 
 
-retrain_color_defaults <- function(traces) {
-  colorDefaults <- traceColorDefaults()
+colorway_retrain <- function(traces, colorway = colorway()) {
+  colorway <- rep(colorway, length.out = length(traces))
   for (i in seq_along(traces)) {
-    # https://github.com/plotly/plotly.js/blob/c83735/src/plots/plots.js#L58
-    idx <- i %% length(colorDefaults)
-    if (idx == 0) idx <- 10
-    newDefault <- colorDefaults[[idx]]
-    for (j in c("marker", "line", "text")) {
-      obj <- traces[[i]][[j]]
-      if (!"color" %in% names(obj)) next
-      alpha <- attr(obj[["color"]], "defaultAlpha")
-      if (is.null(alpha)) next
-      traces[[i]][[j]][["color"]] <- toRGB(colorDefaults[[idx]], alpha)
-    }
+    col <- prefix_class(default(colorway[[i]]), "colorway")
+    traces[[i]] <- rapply(traces[[i]], function(x) { if (inherits(x, "colorway")) alpha_inherit(col, x) else x }, how = "replace")
   }
-  traces
+  traces 
+}
+
+
+# retrieve the alpha of an 'old' color code and apply it to a new color code
+alpha_inherit <- function(new, old) {
+  # should return the alpha in a rgba() code
+  alphas <- as.numeric(col2rgb(rgb2hex(old), alpha = TRUE)["alpha", ] / 255)
+  prefix_class(default(toRGB(new, alphas)), "colorway")
 }
