@@ -1,8 +1,29 @@
-from plotly.basedatatypes import BaseTraceHierarchyType
-import copy
+from plotly.basedatatypes import BaseTraceHierarchyType as _BaseTraceHierarchyType
+import copy as _copy
 
 
-class ErrorY(BaseTraceHierarchyType):
+class ErrorY(_BaseTraceHierarchyType):
+
+    # class properties
+    # --------------------
+    _parent_path_str = "bar"
+    _path_str = "bar.error_y"
+    _valid_props = {
+        "array",
+        "arrayminus",
+        "arrayminussrc",
+        "arraysrc",
+        "color",
+        "symmetric",
+        "thickness",
+        "traceref",
+        "tracerefminus",
+        "type",
+        "value",
+        "valueminus",
+        "visible",
+        "width",
+    }
 
     # array
     # -----
@@ -19,11 +40,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         numpy.ndarray
         """
-        return self['array']
+        return self["array"]
 
     @array.setter
     def array(self, val):
-        self['array'] = val
+        self["array"] = val
 
     # arrayminus
     # ----------
@@ -41,18 +62,19 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         numpy.ndarray
         """
-        return self['arrayminus']
+        return self["arrayminus"]
 
     @arrayminus.setter
     def arrayminus(self, val):
-        self['arrayminus'] = val
+        self["arrayminus"] = val
 
     # arrayminussrc
     # -------------
     @property
     def arrayminussrc(self):
         """
-        Sets the source reference on plot.ly for  arrayminus .
+        Sets the source reference on Chart Studio Cloud for  arrayminus
+        .
     
         The 'arrayminussrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -61,18 +83,18 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['arrayminussrc']
+        return self["arrayminussrc"]
 
     @arrayminussrc.setter
     def arrayminussrc(self, val):
-        self['arrayminussrc'] = val
+        self["arrayminussrc"] = val
 
     # arraysrc
     # --------
     @property
     def arraysrc(self):
         """
-        Sets the source reference on plot.ly for  array .
+        Sets the source reference on Chart Studio Cloud for  array .
     
         The 'arraysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -81,11 +103,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['arraysrc']
+        return self["arraysrc"]
 
     @arraysrc.setter
     def arraysrc(self, val):
-        self['arraysrc'] = val
+        self["arraysrc"] = val
 
     # color
     # -----
@@ -129,22 +151,22 @@ class ErrorY(BaseTraceHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
 
         Returns
         -------
         str
         """
-        return self['color']
+        return self["color"]
 
     @color.setter
     def color(self, val):
-        self['color'] = val
+        self["color"] = val
 
     # symmetric
     # ---------
@@ -162,11 +184,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['symmetric']
+        return self["symmetric"]
 
     @symmetric.setter
     def symmetric(self, val):
-        self['symmetric'] = val
+        self["symmetric"] = val
 
     # thickness
     # ---------
@@ -182,11 +204,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['thickness']
+        return self["thickness"]
 
     @thickness.setter
     def thickness(self, val):
-        self['thickness'] = val
+        self["thickness"] = val
 
     # traceref
     # --------
@@ -201,11 +223,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         int
         """
-        return self['traceref']
+        return self["traceref"]
 
     @traceref.setter
     def traceref(self, val):
-        self['traceref'] = val
+        self["traceref"] = val
 
     # tracerefminus
     # -------------
@@ -220,11 +242,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         int
         """
-        return self['tracerefminus']
+        return self["tracerefminus"]
 
     @tracerefminus.setter
     def tracerefminus(self, val):
-        self['tracerefminus'] = val
+        self["tracerefminus"] = val
 
     # type
     # ----
@@ -236,7 +258,7 @@ class ErrorY(BaseTraceHierarchyType):
         constant in `value`. If "percent", the bar lengths correspond
         to a percentage of underlying data. Set this percentage in
         `value`. If "sqrt", the bar lengths correspond to the sqaure of
-        the underlying data. If "array", the bar lengths are set with
+        the underlying data. If "data", the bar lengths are set with
         data set `array`.
     
         The 'type' property is an enumeration that may be specified as:
@@ -247,11 +269,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         Any
         """
-        return self['type']
+        return self["type"]
 
     @type.setter
     def type(self, val):
-        self['type'] = val
+        self["type"] = val
 
     # value
     # -----
@@ -269,11 +291,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['value']
+        return self["value"]
 
     @value.setter
     def value(self, val):
-        self['value'] = val
+        self["value"] = val
 
     # valueminus
     # ----------
@@ -292,11 +314,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['valueminus']
+        return self["valueminus"]
 
     @valueminus.setter
     def valueminus(self, val):
-        self['valueminus'] = val
+        self["valueminus"] = val
 
     # visible
     # -------
@@ -312,11 +334,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['visible']
+        return self["visible"]
 
     @visible.setter
     def visible(self, val):
-        self['visible'] = val
+        self["visible"] = val
 
     # width
     # -----
@@ -333,17 +355,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['width']
+        return self["width"]
 
     @width.setter
     def width(self, val):
-        self['width'] = val
-
-    # property parent name
-    # --------------------
-    @property
-    def _parent_path_str(self):
-        return 'bar'
+        self["width"] = val
 
     # Self properties description
     # ---------------------------
@@ -360,9 +376,11 @@ class ErrorY(BaseTraceHierarchyType):
             (horizontal) bars Values are plotted relative to the
             underlying data.
         arrayminussrc
-            Sets the source reference on plot.ly for  arrayminus .
+            Sets the source reference on Chart Studio Cloud for
+            arrayminus .
         arraysrc
-            Sets the source reference on plot.ly for  array .
+            Sets the source reference on Chart Studio Cloud for
+            array .
         color
             Sets the stoke color of the error bars.
         symmetric
@@ -382,7 +400,7 @@ class ErrorY(BaseTraceHierarchyType):
             lengths correspond to a percentage of underlying data.
             Set this percentage in `value`. If "sqrt", the bar
             lengths correspond to the sqaure of the underlying
-            data. If "array", the bar lengths are set with data set
+            data. If "data", the bar lengths are set with data set
             `array`.
         value
             Sets the value of either the percentage (if `type` is
@@ -429,7 +447,7 @@ class ErrorY(BaseTraceHierarchyType):
         ----------
         arg
             dict of properties compatible with this constructor or
-            an instance of plotly.graph_objs.bar.ErrorY
+            an instance of :class:`plotly.graph_objs.bar.ErrorY`
         array
             Sets the data corresponding the length of each error
             bar. Values are plotted relative to the underlying
@@ -440,9 +458,11 @@ class ErrorY(BaseTraceHierarchyType):
             (horizontal) bars Values are plotted relative to the
             underlying data.
         arrayminussrc
-            Sets the source reference on plot.ly for  arrayminus .
+            Sets the source reference on Chart Studio Cloud for
+            arrayminus .
         arraysrc
-            Sets the source reference on plot.ly for  array .
+            Sets the source reference on Chart Studio Cloud for
+            array .
         color
             Sets the stoke color of the error bars.
         symmetric
@@ -462,7 +482,7 @@ class ErrorY(BaseTraceHierarchyType):
             lengths correspond to a percentage of underlying data.
             Set this percentage in `value`. If "sqrt", the bar
             lengths correspond to the sqaure of the underlying
-            data. If "array", the bar lengths are set with data set
+            data. If "data", the bar lengths are set with data set
             `array`.
         value
             Sets the value of either the percentage (if `type` is
@@ -486,7 +506,11 @@ class ErrorY(BaseTraceHierarchyType):
         -------
         ErrorY
         """
-        super(ErrorY, self).__init__('error_y')
+        super(ErrorY, self).__init__("error_y")
+
+        if "_parent" in kwargs:
+            self._parent = kwargs["_parent"]
+            return
 
         # Validate arg
         # ------------
@@ -495,72 +519,78 @@ class ErrorY(BaseTraceHierarchyType):
         elif isinstance(arg, self.__class__):
             arg = arg.to_plotly_json()
         elif isinstance(arg, dict):
-            arg = copy.copy(arg)
+            arg = _copy.copy(arg)
         else:
             raise ValueError(
                 """\
 The first argument to the plotly.graph_objs.bar.ErrorY 
 constructor must be a dict or 
-an instance of plotly.graph_objs.bar.ErrorY"""
+an instance of :class:`plotly.graph_objs.bar.ErrorY`"""
             )
 
         # Handle skip_invalid
         # -------------------
-        self._skip_invalid = kwargs.pop('skip_invalid', False)
-
-        # Import validators
-        # -----------------
-        from plotly.validators.bar import (error_y as v_error_y)
-
-        # Initialize validators
-        # ---------------------
-        self._validators['array'] = v_error_y.ArrayValidator()
-        self._validators['arrayminus'] = v_error_y.ArrayminusValidator()
-        self._validators['arrayminussrc'] = v_error_y.ArrayminussrcValidator()
-        self._validators['arraysrc'] = v_error_y.ArraysrcValidator()
-        self._validators['color'] = v_error_y.ColorValidator()
-        self._validators['symmetric'] = v_error_y.SymmetricValidator()
-        self._validators['thickness'] = v_error_y.ThicknessValidator()
-        self._validators['traceref'] = v_error_y.TracerefValidator()
-        self._validators['tracerefminus'] = v_error_y.TracerefminusValidator()
-        self._validators['type'] = v_error_y.TypeValidator()
-        self._validators['value'] = v_error_y.ValueValidator()
-        self._validators['valueminus'] = v_error_y.ValueminusValidator()
-        self._validators['visible'] = v_error_y.VisibleValidator()
-        self._validators['width'] = v_error_y.WidthValidator()
+        self._skip_invalid = kwargs.pop("skip_invalid", False)
+        self._validate = kwargs.pop("_validate", True)
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop('array', None)
-        self['array'] = array if array is not None else _v
-        _v = arg.pop('arrayminus', None)
-        self['arrayminus'] = arrayminus if arrayminus is not None else _v
-        _v = arg.pop('arrayminussrc', None)
-        self['arrayminussrc'
-            ] = arrayminussrc if arrayminussrc is not None else _v
-        _v = arg.pop('arraysrc', None)
-        self['arraysrc'] = arraysrc if arraysrc is not None else _v
-        _v = arg.pop('color', None)
-        self['color'] = color if color is not None else _v
-        _v = arg.pop('symmetric', None)
-        self['symmetric'] = symmetric if symmetric is not None else _v
-        _v = arg.pop('thickness', None)
-        self['thickness'] = thickness if thickness is not None else _v
-        _v = arg.pop('traceref', None)
-        self['traceref'] = traceref if traceref is not None else _v
-        _v = arg.pop('tracerefminus', None)
-        self['tracerefminus'
-            ] = tracerefminus if tracerefminus is not None else _v
-        _v = arg.pop('type', None)
-        self['type'] = type if type is not None else _v
-        _v = arg.pop('value', None)
-        self['value'] = value if value is not None else _v
-        _v = arg.pop('valueminus', None)
-        self['valueminus'] = valueminus if valueminus is not None else _v
-        _v = arg.pop('visible', None)
-        self['visible'] = visible if visible is not None else _v
-        _v = arg.pop('width', None)
-        self['width'] = width if width is not None else _v
+        _v = arg.pop("array", None)
+        _v = array if array is not None else _v
+        if _v is not None:
+            self["array"] = _v
+        _v = arg.pop("arrayminus", None)
+        _v = arrayminus if arrayminus is not None else _v
+        if _v is not None:
+            self["arrayminus"] = _v
+        _v = arg.pop("arrayminussrc", None)
+        _v = arrayminussrc if arrayminussrc is not None else _v
+        if _v is not None:
+            self["arrayminussrc"] = _v
+        _v = arg.pop("arraysrc", None)
+        _v = arraysrc if arraysrc is not None else _v
+        if _v is not None:
+            self["arraysrc"] = _v
+        _v = arg.pop("color", None)
+        _v = color if color is not None else _v
+        if _v is not None:
+            self["color"] = _v
+        _v = arg.pop("symmetric", None)
+        _v = symmetric if symmetric is not None else _v
+        if _v is not None:
+            self["symmetric"] = _v
+        _v = arg.pop("thickness", None)
+        _v = thickness if thickness is not None else _v
+        if _v is not None:
+            self["thickness"] = _v
+        _v = arg.pop("traceref", None)
+        _v = traceref if traceref is not None else _v
+        if _v is not None:
+            self["traceref"] = _v
+        _v = arg.pop("tracerefminus", None)
+        _v = tracerefminus if tracerefminus is not None else _v
+        if _v is not None:
+            self["tracerefminus"] = _v
+        _v = arg.pop("type", None)
+        _v = type if type is not None else _v
+        if _v is not None:
+            self["type"] = _v
+        _v = arg.pop("value", None)
+        _v = value if value is not None else _v
+        if _v is not None:
+            self["value"] = _v
+        _v = arg.pop("valueminus", None)
+        _v = valueminus if valueminus is not None else _v
+        if _v is not None:
+            self["valueminus"] = _v
+        _v = arg.pop("visible", None)
+        _v = visible if visible is not None else _v
+        if _v is not None:
+            self["visible"] = _v
+        _v = arg.pop("width", None)
+        _v = width if width is not None else _v
+        if _v is not None:
+            self["width"] = _v
 
         # Process unknown kwargs
         # ----------------------
