@@ -1,8 +1,27 @@
-from plotly.basedatatypes import BaseTraceHierarchyType
-import copy
+from plotly.basedatatypes import BaseTraceHierarchyType as _BaseTraceHierarchyType
+import copy as _copy
 
 
-class Line(BaseTraceHierarchyType):
+class Line(_BaseTraceHierarchyType):
+
+    # class properties
+    # --------------------
+    _parent_path_str = "parcoords"
+    _path_str = "parcoords.line"
+    _valid_props = {
+        "autocolorscale",
+        "cauto",
+        "cmax",
+        "cmid",
+        "cmin",
+        "color",
+        "coloraxis",
+        "colorbar",
+        "colorscale",
+        "colorsrc",
+        "reversescale",
+        "showscale",
+    }
 
     # autocolorscale
     # --------------
@@ -24,11 +43,11 @@ class Line(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['autocolorscale']
+        return self["autocolorscale"]
 
     @autocolorscale.setter
     def autocolorscale(self, val):
-        self['autocolorscale'] = val
+        self["autocolorscale"] = val
 
     # cauto
     # -----
@@ -48,11 +67,11 @@ class Line(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['cauto']
+        return self["cauto"]
 
     @cauto.setter
     def cauto(self, val):
-        self['cauto'] = val
+        self["cauto"] = val
 
     # cmax
     # ----
@@ -71,11 +90,35 @@ class Line(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['cmax']
+        return self["cmax"]
 
     @cmax.setter
     def cmax(self, val):
-        self['cmax'] = val
+        self["cmax"] = val
+
+    # cmid
+    # ----
+    @property
+    def cmid(self):
+        """
+        Sets the mid-point of the color domain by scaling `line.cmin`
+        and/or `line.cmax` to be equidistant to this point. Has an
+        effect only if in `line.color`is set to a numerical array.
+        Value should have the same units as in `line.color`. Has no
+        effect when `line.cauto` is `false`.
+    
+        The 'cmid' property is a number and may be specified as:
+          - An int or float
+
+        Returns
+        -------
+        int|float
+        """
+        return self["cmid"]
+
+    @cmid.setter
+    def cmid(self, val):
+        self["cmid"] = val
 
     # cmin
     # ----
@@ -94,11 +137,11 @@ class Line(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['cmin']
+        return self["cmin"]
 
     @cmin.setter
     def cmin(self, val):
-        self['cmin'] = val
+        self["cmin"] = val
 
     # color
     # -----
@@ -145,12 +188,12 @@ class Line(BaseTraceHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
           - A number that will be interpreted as a color
             according to parcoords.line.colorscale
           - A list or array of any of the above
@@ -159,11 +202,38 @@ class Line(BaseTraceHierarchyType):
         -------
         str|numpy.ndarray
         """
-        return self['color']
+        return self["color"]
 
     @color.setter
     def color(self, val):
-        self['color'] = val
+        self["color"] = val
+
+    # coloraxis
+    # ---------
+    @property
+    def coloraxis(self):
+        """
+        Sets a reference to a shared color axis. References to these
+        shared color axes are "coloraxis", "coloraxis2", "coloraxis3",
+        etc. Settings for these shared color axes are set in the
+        layout, under `layout.coloraxis`, `layout.coloraxis2`, etc.
+        Note that multiple color scales can be linked to the same color
+        axis.
+    
+        The 'coloraxis' property is an identifier of a particular
+        subplot, of type 'coloraxis', that may be specified as the string 'coloraxis'
+        optionally followed by an integer >= 1
+        (e.g. 'coloraxis', 'coloraxis1', 'coloraxis2', 'coloraxis3', etc.)
+
+        Returns
+        -------
+        str
+        """
+        return self["coloraxis"]
+
+    @coloraxis.setter
+    def coloraxis(self, val):
+        self["coloraxis"] = val
 
     # colorbar
     # --------
@@ -172,7 +242,7 @@ class Line(BaseTraceHierarchyType):
         """
         The 'colorbar' property is an instance of ColorBar
         that may be specified as:
-          - An instance of plotly.graph_objs.parcoords.line.ColorBar
+          - An instance of :class:`plotly.graph_objs.parcoords.line.ColorBar`
           - A dict of string/value properties that will be passed
             to the ColorBar constructor
     
@@ -292,20 +362,21 @@ class Line(BaseTraceHierarchyType):
                 tickformat
                     Sets the tick label formatting rule using d3
                     formatting mini-languages which are very
-                    similar to those in Python. For numbers, see: h
-                    ttps://github.com/d3/d3-format/blob/master/READ
-                    ME.md#locale_format And for dates see:
-                    https://github.com/d3/d3-time-
-                    format/blob/master/README.md#locale_format We
-                    add one item to d3's date formatter: "%{n}f"
+                    similar to those in Python. For numbers, see:
+                    https://github.com/d3/d3-3.x-api-
+                    reference/blob/master/Formatting.md#d3_format
+                    And for dates see:
+                    https://github.com/d3/d3-3.x-api-
+                    reference/blob/master/Time-Formatting.md#format
+                    We add one item to d3's date formatter: "%{n}f"
                     for fractional seconds with n digits. For
                     example, *2016-10-13 09:15:23.456* with
                     tickformat "%H~%M~%S.%2f" would display
                     "09~15~23.46"
                 tickformatstops
-                    plotly.graph_objs.parcoords.line.colorbar.Tickf
-                    ormatstop instance or dict with compatible
-                    properties
+                    A tuple of :class:`plotly.graph_objects.parcoor
+                    ds.line.colorbar.Tickformatstop` instances or
+                    dicts with compatible properties
                 tickformatstopdefaults
                     When used in a template (as layout.template.dat
                     a.parcoords.line.colorbar.tickformatstopdefault
@@ -340,20 +411,21 @@ class Line(BaseTraceHierarchyType):
                     `tickmode` is set to "array". Used with
                     `tickvals`.
                 ticktextsrc
-                    Sets the source reference on plot.ly for
-                    ticktext .
+                    Sets the source reference on Chart Studio Cloud
+                    for  ticktext .
                 tickvals
                     Sets the values at which ticks on this axis
                     appear. Only has an effect if `tickmode` is set
                     to "array". Used with `ticktext`.
                 tickvalssrc
-                    Sets the source reference on plot.ly for
-                    tickvals .
+                    Sets the source reference on Chart Studio Cloud
+                    for  tickvals .
                 tickwidth
                     Sets the tick width (in px).
                 title
-                    plotly.graph_objs.parcoords.line.colorbar.Title
-                    instance or dict with compatible properties
+                    :class:`plotly.graph_objects.parcoords.line.col
+                    orbar.Title` instance or dict with compatible
+                    properties
                 titlefont
                     Deprecated: Please use
                     parcoords.line.colorbar.title.font instead.
@@ -393,11 +465,11 @@ class Line(BaseTraceHierarchyType):
         -------
         plotly.graph_objs.parcoords.line.ColorBar
         """
-        return self['colorbar']
+        return self["colorbar"]
 
     @colorbar.setter
     def colorbar(self, val):
-        self['colorbar'] = val
+        self["colorbar"] = val
 
     # colorscale
     # ----------
@@ -409,7 +481,7 @@ class Line(BaseTraceHierarchyType):
         containing arrays mapping a normalized value to an rgb, rgba,
         hex, hsl, hsv, or named color string. At minimum, a mapping for
         the lowest (0) and highest (1) values are required. For
-        example, `[[0, 'rgb(0,0,255)', [1, 'rgb(255,0,0)']]`. To
+        example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To
         control the bounds of the colorscale in color space,
         use`line.cmin` and `line.cmax`. Alternatively, `colorscale` may
         be a palette name string of the following list: Greys,YlGnBu,Gr
@@ -418,31 +490,46 @@ class Line(BaseTraceHierarchyType):
     
         The 'colorscale' property is a colorscale and may be
         specified as:
+          - A list of colors that will be spaced evenly to create the colorscale.
+            Many predefined colorscale lists are included in the sequential, diverging,
+            and cyclical modules in the plotly.colors package.
           - A list of 2-element lists where the first element is the
             normalized color level value (starting at 0 and ending at 1), 
             and the second item is a valid color string.
             (e.g. [[0, 'green'], [0.5, 'red'], [1.0, 'rgb(0, 0, 255)']])
           - One of the following named colorscales:
-                ['Greys', 'YlGnBu', 'Greens', 'YlOrRd', 'Bluered', 'RdBu',
-                'Reds', 'Blues', 'Picnic', 'Rainbow', 'Portland', 'Jet',
-                'Hot', 'Blackbody', 'Earth', 'Electric', 'Viridis', 'Cividis']
+                ['aggrnyl', 'agsunset', 'algae', 'amp', 'armyrose', 'balance',
+                 'blackbody', 'bluered', 'blues', 'blugrn', 'bluyl', 'brbg',
+                 'brwnyl', 'bugn', 'bupu', 'burg', 'burgyl', 'cividis', 'curl',
+                 'darkmint', 'deep', 'delta', 'dense', 'earth', 'edge', 'electric',
+                 'emrld', 'fall', 'geyser', 'gnbu', 'gray', 'greens', 'greys',
+                 'haline', 'hot', 'hsv', 'ice', 'icefire', 'inferno', 'jet',
+                 'magenta', 'magma', 'matter', 'mint', 'mrybm', 'mygbm', 'oranges',
+                 'orrd', 'oryel', 'peach', 'phase', 'picnic', 'pinkyl', 'piyg',
+                 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn', 'puor',
+                 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu', 'rdgy',
+                 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar', 'spectral',
+                 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn', 'tealrose',
+                 'tempo', 'temps', 'thermal', 'tropic', 'turbid', 'twilight',
+                 'viridis', 'ylgn', 'ylgnbu', 'ylorbr', 'ylorrd'].
+            Appending '_r' to a named colorscale reverses it.
 
         Returns
         -------
         str
         """
-        return self['colorscale']
+        return self["colorscale"]
 
     @colorscale.setter
     def colorscale(self, val):
-        self['colorscale'] = val
+        self["colorscale"] = val
 
     # colorsrc
     # --------
     @property
     def colorsrc(self):
         """
-        Sets the source reference on plot.ly for  color .
+        Sets the source reference on Chart Studio Cloud for  color .
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -451,11 +538,11 @@ class Line(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['colorsrc']
+        return self["colorsrc"]
 
     @colorsrc.setter
     def colorsrc(self, val):
-        self['colorsrc'] = val
+        self["colorsrc"] = val
 
     # reversescale
     # ------------
@@ -474,11 +561,11 @@ class Line(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['reversescale']
+        return self["reversescale"]
 
     @reversescale.setter
     def reversescale(self, val):
-        self['reversescale'] = val
+        self["reversescale"] = val
 
     # showscale
     # ---------
@@ -496,17 +583,11 @@ class Line(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['showscale']
+        return self["showscale"]
 
     @showscale.setter
     def showscale(self, val):
-        self['showscale'] = val
-
-    # property parent name
-    # --------------------
-    @property
-    def _parent_path_str(self):
-        return 'parcoords'
+        self["showscale"] = val
 
     # Self properties description
     # ---------------------------
@@ -534,6 +615,13 @@ class Line(BaseTraceHierarchyType):
             only if in `line.color`is set to a numerical array.
             Value should have the same units as in `line.color` and
             if set, `line.cmin` must be set as well.
+        cmid
+            Sets the mid-point of the color domain by scaling
+            `line.cmin` and/or `line.cmax` to be equidistant to
+            this point. Has an effect only if in `line.color`is set
+            to a numerical array. Value should have the same units
+            as in `line.color`. Has no effect when `line.cauto` is
+            `false`.
         cmin
             Sets the lower bound of the color domain. Has an effect
             only if in `line.color`is set to a numerical array.
@@ -545,9 +633,16 @@ class Line(BaseTraceHierarchyType):
             colorscale relative to the max and min values of the
             array or relative to `line.cmin` and `line.cmax` if
             set.
+        coloraxis
+            Sets a reference to a shared color axis. References to
+            these shared color axes are "coloraxis", "coloraxis2",
+            "coloraxis3", etc. Settings for these shared color axes
+            are set in the layout, under `layout.coloraxis`,
+            `layout.coloraxis2`, etc. Note that multiple color
+            scales can be linked to the same color axis.
         colorbar
-            plotly.graph_objs.parcoords.line.ColorBar instance or
-            dict with compatible properties
+            :class:`plotly.graph_objects.parcoords.line.ColorBar`
+            instance or dict with compatible properties
         colorscale
             Sets the colorscale. Has an effect only if in
             `line.color`is set to a numerical array. The colorscale
@@ -555,7 +650,7 @@ class Line(BaseTraceHierarchyType):
             value to an rgb, rgba, hex, hsl, hsv, or named color
             string. At minimum, a mapping for the lowest (0) and
             highest (1) values are required. For example, `[[0,
-            'rgb(0,0,255)', [1, 'rgb(255,0,0)']]`. To control the
+            'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To control the
             bounds of the colorscale in color space, use`line.cmin`
             and `line.cmax`. Alternatively, `colorscale` may be a
             palette name string of the following list: Greys,YlGnBu
@@ -563,7 +658,8 @@ class Line(BaseTraceHierarchyType):
             ortland,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividi
             s.
         colorsrc
-            Sets the source reference on plot.ly for  color .
+            Sets the source reference on Chart Studio Cloud for
+            color .
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `line.color`is set to a numerical array. If true,
@@ -582,8 +678,10 @@ class Line(BaseTraceHierarchyType):
         autocolorscale=None,
         cauto=None,
         cmax=None,
+        cmid=None,
         cmin=None,
         color=None,
+        coloraxis=None,
         colorbar=None,
         colorscale=None,
         colorsrc=None,
@@ -598,7 +696,8 @@ class Line(BaseTraceHierarchyType):
         ----------
         arg
             dict of properties compatible with this constructor or
-            an instance of plotly.graph_objs.parcoords.Line
+            an instance of
+            :class:`plotly.graph_objs.parcoords.Line`
         autocolorscale
             Determines whether the colorscale is a default palette
             (`autocolorscale: true`) or the palette determined by
@@ -620,6 +719,13 @@ class Line(BaseTraceHierarchyType):
             only if in `line.color`is set to a numerical array.
             Value should have the same units as in `line.color` and
             if set, `line.cmin` must be set as well.
+        cmid
+            Sets the mid-point of the color domain by scaling
+            `line.cmin` and/or `line.cmax` to be equidistant to
+            this point. Has an effect only if in `line.color`is set
+            to a numerical array. Value should have the same units
+            as in `line.color`. Has no effect when `line.cauto` is
+            `false`.
         cmin
             Sets the lower bound of the color domain. Has an effect
             only if in `line.color`is set to a numerical array.
@@ -631,9 +737,16 @@ class Line(BaseTraceHierarchyType):
             colorscale relative to the max and min values of the
             array or relative to `line.cmin` and `line.cmax` if
             set.
+        coloraxis
+            Sets a reference to a shared color axis. References to
+            these shared color axes are "coloraxis", "coloraxis2",
+            "coloraxis3", etc. Settings for these shared color axes
+            are set in the layout, under `layout.coloraxis`,
+            `layout.coloraxis2`, etc. Note that multiple color
+            scales can be linked to the same color axis.
         colorbar
-            plotly.graph_objs.parcoords.line.ColorBar instance or
-            dict with compatible properties
+            :class:`plotly.graph_objects.parcoords.line.ColorBar`
+            instance or dict with compatible properties
         colorscale
             Sets the colorscale. Has an effect only if in
             `line.color`is set to a numerical array. The colorscale
@@ -641,7 +754,7 @@ class Line(BaseTraceHierarchyType):
             value to an rgb, rgba, hex, hsl, hsv, or named color
             string. At minimum, a mapping for the lowest (0) and
             highest (1) values are required. For example, `[[0,
-            'rgb(0,0,255)', [1, 'rgb(255,0,0)']]`. To control the
+            'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To control the
             bounds of the colorscale in color space, use`line.cmin`
             and `line.cmax`. Alternatively, `colorscale` may be a
             palette name string of the following list: Greys,YlGnBu
@@ -649,7 +762,8 @@ class Line(BaseTraceHierarchyType):
             ortland,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividi
             s.
         colorsrc
-            Sets the source reference on plot.ly for  color .
+            Sets the source reference on Chart Studio Cloud for
+            color .
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `line.color`is set to a numerical array. If true,
@@ -665,7 +779,11 @@ class Line(BaseTraceHierarchyType):
         -------
         Line
         """
-        super(Line, self).__init__('line')
+        super(Line, self).__init__("line")
+
+        if "_parent" in kwargs:
+            self._parent = kwargs["_parent"]
+            return
 
         # Validate arg
         # ------------
@@ -674,59 +792,70 @@ class Line(BaseTraceHierarchyType):
         elif isinstance(arg, self.__class__):
             arg = arg.to_plotly_json()
         elif isinstance(arg, dict):
-            arg = copy.copy(arg)
+            arg = _copy.copy(arg)
         else:
             raise ValueError(
                 """\
 The first argument to the plotly.graph_objs.parcoords.Line 
 constructor must be a dict or 
-an instance of plotly.graph_objs.parcoords.Line"""
+an instance of :class:`plotly.graph_objs.parcoords.Line`"""
             )
 
         # Handle skip_invalid
         # -------------------
-        self._skip_invalid = kwargs.pop('skip_invalid', False)
-
-        # Import validators
-        # -----------------
-        from plotly.validators.parcoords import (line as v_line)
-
-        # Initialize validators
-        # ---------------------
-        self._validators['autocolorscale'] = v_line.AutocolorscaleValidator()
-        self._validators['cauto'] = v_line.CautoValidator()
-        self._validators['cmax'] = v_line.CmaxValidator()
-        self._validators['cmin'] = v_line.CminValidator()
-        self._validators['color'] = v_line.ColorValidator()
-        self._validators['colorbar'] = v_line.ColorBarValidator()
-        self._validators['colorscale'] = v_line.ColorscaleValidator()
-        self._validators['colorsrc'] = v_line.ColorsrcValidator()
-        self._validators['reversescale'] = v_line.ReversescaleValidator()
-        self._validators['showscale'] = v_line.ShowscaleValidator()
+        self._skip_invalid = kwargs.pop("skip_invalid", False)
+        self._validate = kwargs.pop("_validate", True)
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop('autocolorscale', None)
-        self['autocolorscale'
-            ] = autocolorscale if autocolorscale is not None else _v
-        _v = arg.pop('cauto', None)
-        self['cauto'] = cauto if cauto is not None else _v
-        _v = arg.pop('cmax', None)
-        self['cmax'] = cmax if cmax is not None else _v
-        _v = arg.pop('cmin', None)
-        self['cmin'] = cmin if cmin is not None else _v
-        _v = arg.pop('color', None)
-        self['color'] = color if color is not None else _v
-        _v = arg.pop('colorbar', None)
-        self['colorbar'] = colorbar if colorbar is not None else _v
-        _v = arg.pop('colorscale', None)
-        self['colorscale'] = colorscale if colorscale is not None else _v
-        _v = arg.pop('colorsrc', None)
-        self['colorsrc'] = colorsrc if colorsrc is not None else _v
-        _v = arg.pop('reversescale', None)
-        self['reversescale'] = reversescale if reversescale is not None else _v
-        _v = arg.pop('showscale', None)
-        self['showscale'] = showscale if showscale is not None else _v
+        _v = arg.pop("autocolorscale", None)
+        _v = autocolorscale if autocolorscale is not None else _v
+        if _v is not None:
+            self["autocolorscale"] = _v
+        _v = arg.pop("cauto", None)
+        _v = cauto if cauto is not None else _v
+        if _v is not None:
+            self["cauto"] = _v
+        _v = arg.pop("cmax", None)
+        _v = cmax if cmax is not None else _v
+        if _v is not None:
+            self["cmax"] = _v
+        _v = arg.pop("cmid", None)
+        _v = cmid if cmid is not None else _v
+        if _v is not None:
+            self["cmid"] = _v
+        _v = arg.pop("cmin", None)
+        _v = cmin if cmin is not None else _v
+        if _v is not None:
+            self["cmin"] = _v
+        _v = arg.pop("color", None)
+        _v = color if color is not None else _v
+        if _v is not None:
+            self["color"] = _v
+        _v = arg.pop("coloraxis", None)
+        _v = coloraxis if coloraxis is not None else _v
+        if _v is not None:
+            self["coloraxis"] = _v
+        _v = arg.pop("colorbar", None)
+        _v = colorbar if colorbar is not None else _v
+        if _v is not None:
+            self["colorbar"] = _v
+        _v = arg.pop("colorscale", None)
+        _v = colorscale if colorscale is not None else _v
+        if _v is not None:
+            self["colorscale"] = _v
+        _v = arg.pop("colorsrc", None)
+        _v = colorsrc if colorsrc is not None else _v
+        if _v is not None:
+            self["colorsrc"] = _v
+        _v = arg.pop("reversescale", None)
+        _v = reversescale if reversescale is not None else _v
+        if _v is not None:
+            self["reversescale"] = _v
+        _v = arg.pop("showscale", None)
+        _v = showscale if showscale is not None else _v
+        if _v is not None:
+            self["showscale"] = _v
 
         # Process unknown kwargs
         # ----------------------
