@@ -1,8 +1,27 @@
-from plotly.basedatatypes import BaseTraceHierarchyType
-import copy
+from plotly.basedatatypes import BaseTraceHierarchyType as _BaseTraceHierarchyType
+import copy as _copy
 
 
-class Line(BaseTraceHierarchyType):
+class Line(_BaseTraceHierarchyType):
+
+    # class properties
+    # --------------------
+    _parent_path_str = "scattercarpet.marker"
+    _path_str = "scattercarpet.marker.line"
+    _valid_props = {
+        "autocolorscale",
+        "cauto",
+        "cmax",
+        "cmid",
+        "cmin",
+        "color",
+        "coloraxis",
+        "colorscale",
+        "colorsrc",
+        "reversescale",
+        "width",
+        "widthsrc",
+    }
 
     # autocolorscale
     # --------------
@@ -24,11 +43,11 @@ class Line(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['autocolorscale']
+        return self["autocolorscale"]
 
     @autocolorscale.setter
     def autocolorscale(self, val):
-        self['autocolorscale'] = val
+        self["autocolorscale"] = val
 
     # cauto
     # -----
@@ -49,11 +68,11 @@ class Line(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['cauto']
+        return self["cauto"]
 
     @cauto.setter
     def cauto(self, val):
-        self['cauto'] = val
+        self["cauto"] = val
 
     # cmax
     # ----
@@ -72,11 +91,36 @@ class Line(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['cmax']
+        return self["cmax"]
 
     @cmax.setter
     def cmax(self, val):
-        self['cmax'] = val
+        self["cmax"] = val
+
+    # cmid
+    # ----
+    @property
+    def cmid(self):
+        """
+        Sets the mid-point of the color domain by scaling
+        `marker.line.cmin` and/or `marker.line.cmax` to be equidistant
+        to this point. Has an effect only if in `marker.line.color`is
+        set to a numerical array. Value should have the same units as
+        in `marker.line.color`. Has no effect when `marker.line.cauto`
+        is `false`.
+    
+        The 'cmid' property is a number and may be specified as:
+          - An int or float
+
+        Returns
+        -------
+        int|float
+        """
+        return self["cmid"]
+
+    @cmid.setter
+    def cmid(self, val):
+        self["cmid"] = val
 
     # cmin
     # ----
@@ -95,11 +139,11 @@ class Line(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['cmin']
+        return self["cmin"]
 
     @cmin.setter
     def cmin(self, val):
-        self['cmin'] = val
+        self["cmin"] = val
 
     # color
     # -----
@@ -146,12 +190,12 @@ class Line(BaseTraceHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
           - A number that will be interpreted as a color
             according to scattercarpet.marker.line.colorscale
           - A list or array of any of the above
@@ -160,11 +204,38 @@ class Line(BaseTraceHierarchyType):
         -------
         str|numpy.ndarray
         """
-        return self['color']
+        return self["color"]
 
     @color.setter
     def color(self, val):
-        self['color'] = val
+        self["color"] = val
+
+    # coloraxis
+    # ---------
+    @property
+    def coloraxis(self):
+        """
+        Sets a reference to a shared color axis. References to these
+        shared color axes are "coloraxis", "coloraxis2", "coloraxis3",
+        etc. Settings for these shared color axes are set in the
+        layout, under `layout.coloraxis`, `layout.coloraxis2`, etc.
+        Note that multiple color scales can be linked to the same color
+        axis.
+    
+        The 'coloraxis' property is an identifier of a particular
+        subplot, of type 'coloraxis', that may be specified as the string 'coloraxis'
+        optionally followed by an integer >= 1
+        (e.g. 'coloraxis', 'coloraxis1', 'coloraxis2', 'coloraxis3', etc.)
+
+        Returns
+        -------
+        str
+        """
+        return self["coloraxis"]
+
+    @coloraxis.setter
+    def coloraxis(self, val):
+        self["coloraxis"] = val
 
     # colorscale
     # ----------
@@ -176,7 +247,7 @@ class Line(BaseTraceHierarchyType):
         must be an array containing arrays mapping a normalized value
         to an rgb, rgba, hex, hsl, hsv, or named color string. At
         minimum, a mapping for the lowest (0) and highest (1) values
-        are required. For example, `[[0, 'rgb(0,0,255)', [1,
+        are required. For example, `[[0, 'rgb(0,0,255)'], [1,
         'rgb(255,0,0)']]`. To control the bounds of the colorscale in
         color space, use`marker.line.cmin` and `marker.line.cmax`.
         Alternatively, `colorscale` may be a palette name string of the
@@ -186,31 +257,46 @@ class Line(BaseTraceHierarchyType):
     
         The 'colorscale' property is a colorscale and may be
         specified as:
+          - A list of colors that will be spaced evenly to create the colorscale.
+            Many predefined colorscale lists are included in the sequential, diverging,
+            and cyclical modules in the plotly.colors package.
           - A list of 2-element lists where the first element is the
             normalized color level value (starting at 0 and ending at 1), 
             and the second item is a valid color string.
             (e.g. [[0, 'green'], [0.5, 'red'], [1.0, 'rgb(0, 0, 255)']])
           - One of the following named colorscales:
-                ['Greys', 'YlGnBu', 'Greens', 'YlOrRd', 'Bluered', 'RdBu',
-                'Reds', 'Blues', 'Picnic', 'Rainbow', 'Portland', 'Jet',
-                'Hot', 'Blackbody', 'Earth', 'Electric', 'Viridis', 'Cividis']
+                ['aggrnyl', 'agsunset', 'algae', 'amp', 'armyrose', 'balance',
+                 'blackbody', 'bluered', 'blues', 'blugrn', 'bluyl', 'brbg',
+                 'brwnyl', 'bugn', 'bupu', 'burg', 'burgyl', 'cividis', 'curl',
+                 'darkmint', 'deep', 'delta', 'dense', 'earth', 'edge', 'electric',
+                 'emrld', 'fall', 'geyser', 'gnbu', 'gray', 'greens', 'greys',
+                 'haline', 'hot', 'hsv', 'ice', 'icefire', 'inferno', 'jet',
+                 'magenta', 'magma', 'matter', 'mint', 'mrybm', 'mygbm', 'oranges',
+                 'orrd', 'oryel', 'peach', 'phase', 'picnic', 'pinkyl', 'piyg',
+                 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn', 'puor',
+                 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu', 'rdgy',
+                 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar', 'spectral',
+                 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn', 'tealrose',
+                 'tempo', 'temps', 'thermal', 'tropic', 'turbid', 'twilight',
+                 'viridis', 'ylgn', 'ylgnbu', 'ylorbr', 'ylorrd'].
+            Appending '_r' to a named colorscale reverses it.
 
         Returns
         -------
         str
         """
-        return self['colorscale']
+        return self["colorscale"]
 
     @colorscale.setter
     def colorscale(self, val):
-        self['colorscale'] = val
+        self["colorscale"] = val
 
     # colorsrc
     # --------
     @property
     def colorsrc(self):
         """
-        Sets the source reference on plot.ly for  color .
+        Sets the source reference on Chart Studio Cloud for  color .
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -219,11 +305,11 @@ class Line(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['colorsrc']
+        return self["colorsrc"]
 
     @colorsrc.setter
     def colorsrc(self, val):
-        self['colorsrc'] = val
+        self["colorsrc"] = val
 
     # reversescale
     # ------------
@@ -243,11 +329,11 @@ class Line(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['reversescale']
+        return self["reversescale"]
 
     @reversescale.setter
     def reversescale(self, val):
-        self['reversescale'] = val
+        self["reversescale"] = val
 
     # width
     # -----
@@ -264,18 +350,18 @@ class Line(BaseTraceHierarchyType):
         -------
         int|float|numpy.ndarray
         """
-        return self['width']
+        return self["width"]
 
     @width.setter
     def width(self, val):
-        self['width'] = val
+        self["width"] = val
 
     # widthsrc
     # --------
     @property
     def widthsrc(self):
         """
-        Sets the source reference on plot.ly for  width .
+        Sets the source reference on Chart Studio Cloud for  width .
     
         The 'widthsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -284,17 +370,11 @@ class Line(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['widthsrc']
+        return self["widthsrc"]
 
     @widthsrc.setter
     def widthsrc(self, val):
-        self['widthsrc'] = val
-
-    # property parent name
-    # --------------------
-    @property
-    def _parent_path_str(self):
-        return 'scattercarpet.marker'
+        self["widthsrc"] = val
 
     # Self properties description
     # ---------------------------
@@ -325,6 +405,13 @@ class Line(BaseTraceHierarchyType):
             array. Value should have the same units as in
             `marker.line.color` and if set, `marker.line.cmin` must
             be set as well.
+        cmid
+            Sets the mid-point of the color domain by scaling
+            `marker.line.cmin` and/or `marker.line.cmax` to be
+            equidistant to this point. Has an effect only if in
+            `marker.line.color`is set to a numerical array. Value
+            should have the same units as in `marker.line.color`.
+            Has no effect when `marker.line.cauto` is `false`.
         cmin
             Sets the lower bound of the color domain. Has an effect
             only if in `marker.line.color`is set to a numerical
@@ -337,6 +424,13 @@ class Line(BaseTraceHierarchyType):
             colorscale relative to the max and min values of the
             array or relative to `marker.line.cmin` and
             `marker.line.cmax` if set.
+        coloraxis
+            Sets a reference to a shared color axis. References to
+            these shared color axes are "coloraxis", "coloraxis2",
+            "coloraxis3", etc. Settings for these shared color axes
+            are set in the layout, under `layout.coloraxis`,
+            `layout.coloraxis2`, etc. Note that multiple color
+            scales can be linked to the same color axis.
         colorscale
             Sets the colorscale. Has an effect only if in
             `marker.line.color`is set to a numerical array. The
@@ -344,7 +438,7 @@ class Line(BaseTraceHierarchyType):
             normalized value to an rgb, rgba, hex, hsl, hsv, or
             named color string. At minimum, a mapping for the
             lowest (0) and highest (1) values are required. For
-            example, `[[0, 'rgb(0,0,255)', [1, 'rgb(255,0,0)']]`.
+            example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`.
             To control the bounds of the colorscale in color space,
             use`marker.line.cmin` and `marker.line.cmax`.
             Alternatively, `colorscale` may be a palette name
@@ -352,7 +446,8 @@ class Line(BaseTraceHierarchyType):
             d,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland,Jet,H
             ot,Blackbody,Earth,Electric,Viridis,Cividis.
         colorsrc
-            Sets the source reference on plot.ly for  color .
+            Sets the source reference on Chart Studio Cloud for
+            color .
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.line.color`is set to a numerical array.
@@ -363,7 +458,8 @@ class Line(BaseTraceHierarchyType):
             Sets the width (in px) of the lines bounding the marker
             points.
         widthsrc
-            Sets the source reference on plot.ly for  width .
+            Sets the source reference on Chart Studio Cloud for
+            width .
         """
 
     def __init__(
@@ -372,8 +468,10 @@ class Line(BaseTraceHierarchyType):
         autocolorscale=None,
         cauto=None,
         cmax=None,
+        cmid=None,
         cmin=None,
         color=None,
+        coloraxis=None,
         colorscale=None,
         colorsrc=None,
         reversescale=None,
@@ -389,7 +487,7 @@ class Line(BaseTraceHierarchyType):
         arg
             dict of properties compatible with this constructor or
             an instance of
-            plotly.graph_objs.scattercarpet.marker.Line
+            :class:`plotly.graph_objs.scattercarpet.marker.Line`
         autocolorscale
             Determines whether the colorscale is a default palette
             (`autocolorscale: true`) or the palette determined by
@@ -414,6 +512,13 @@ class Line(BaseTraceHierarchyType):
             array. Value should have the same units as in
             `marker.line.color` and if set, `marker.line.cmin` must
             be set as well.
+        cmid
+            Sets the mid-point of the color domain by scaling
+            `marker.line.cmin` and/or `marker.line.cmax` to be
+            equidistant to this point. Has an effect only if in
+            `marker.line.color`is set to a numerical array. Value
+            should have the same units as in `marker.line.color`.
+            Has no effect when `marker.line.cauto` is `false`.
         cmin
             Sets the lower bound of the color domain. Has an effect
             only if in `marker.line.color`is set to a numerical
@@ -426,6 +531,13 @@ class Line(BaseTraceHierarchyType):
             colorscale relative to the max and min values of the
             array or relative to `marker.line.cmin` and
             `marker.line.cmax` if set.
+        coloraxis
+            Sets a reference to a shared color axis. References to
+            these shared color axes are "coloraxis", "coloraxis2",
+            "coloraxis3", etc. Settings for these shared color axes
+            are set in the layout, under `layout.coloraxis`,
+            `layout.coloraxis2`, etc. Note that multiple color
+            scales can be linked to the same color axis.
         colorscale
             Sets the colorscale. Has an effect only if in
             `marker.line.color`is set to a numerical array. The
@@ -433,7 +545,7 @@ class Line(BaseTraceHierarchyType):
             normalized value to an rgb, rgba, hex, hsl, hsv, or
             named color string. At minimum, a mapping for the
             lowest (0) and highest (1) values are required. For
-            example, `[[0, 'rgb(0,0,255)', [1, 'rgb(255,0,0)']]`.
+            example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`.
             To control the bounds of the colorscale in color space,
             use`marker.line.cmin` and `marker.line.cmax`.
             Alternatively, `colorscale` may be a palette name
@@ -441,7 +553,8 @@ class Line(BaseTraceHierarchyType):
             d,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland,Jet,H
             ot,Blackbody,Earth,Electric,Viridis,Cividis.
         colorsrc
-            Sets the source reference on plot.ly for  color .
+            Sets the source reference on Chart Studio Cloud for
+            color .
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.line.color`is set to a numerical array.
@@ -452,13 +565,18 @@ class Line(BaseTraceHierarchyType):
             Sets the width (in px) of the lines bounding the marker
             points.
         widthsrc
-            Sets the source reference on plot.ly for  width .
+            Sets the source reference on Chart Studio Cloud for
+            width .
 
         Returns
         -------
         Line
         """
-        super(Line, self).__init__('line')
+        super(Line, self).__init__("line")
+
+        if "_parent" in kwargs:
+            self._parent = kwargs["_parent"]
+            return
 
         # Validate arg
         # ------------
@@ -467,59 +585,70 @@ class Line(BaseTraceHierarchyType):
         elif isinstance(arg, self.__class__):
             arg = arg.to_plotly_json()
         elif isinstance(arg, dict):
-            arg = copy.copy(arg)
+            arg = _copy.copy(arg)
         else:
             raise ValueError(
                 """\
 The first argument to the plotly.graph_objs.scattercarpet.marker.Line 
 constructor must be a dict or 
-an instance of plotly.graph_objs.scattercarpet.marker.Line"""
+an instance of :class:`plotly.graph_objs.scattercarpet.marker.Line`"""
             )
 
         # Handle skip_invalid
         # -------------------
-        self._skip_invalid = kwargs.pop('skip_invalid', False)
-
-        # Import validators
-        # -----------------
-        from plotly.validators.scattercarpet.marker import (line as v_line)
-
-        # Initialize validators
-        # ---------------------
-        self._validators['autocolorscale'] = v_line.AutocolorscaleValidator()
-        self._validators['cauto'] = v_line.CautoValidator()
-        self._validators['cmax'] = v_line.CmaxValidator()
-        self._validators['cmin'] = v_line.CminValidator()
-        self._validators['color'] = v_line.ColorValidator()
-        self._validators['colorscale'] = v_line.ColorscaleValidator()
-        self._validators['colorsrc'] = v_line.ColorsrcValidator()
-        self._validators['reversescale'] = v_line.ReversescaleValidator()
-        self._validators['width'] = v_line.WidthValidator()
-        self._validators['widthsrc'] = v_line.WidthsrcValidator()
+        self._skip_invalid = kwargs.pop("skip_invalid", False)
+        self._validate = kwargs.pop("_validate", True)
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop('autocolorscale', None)
-        self['autocolorscale'
-            ] = autocolorscale if autocolorscale is not None else _v
-        _v = arg.pop('cauto', None)
-        self['cauto'] = cauto if cauto is not None else _v
-        _v = arg.pop('cmax', None)
-        self['cmax'] = cmax if cmax is not None else _v
-        _v = arg.pop('cmin', None)
-        self['cmin'] = cmin if cmin is not None else _v
-        _v = arg.pop('color', None)
-        self['color'] = color if color is not None else _v
-        _v = arg.pop('colorscale', None)
-        self['colorscale'] = colorscale if colorscale is not None else _v
-        _v = arg.pop('colorsrc', None)
-        self['colorsrc'] = colorsrc if colorsrc is not None else _v
-        _v = arg.pop('reversescale', None)
-        self['reversescale'] = reversescale if reversescale is not None else _v
-        _v = arg.pop('width', None)
-        self['width'] = width if width is not None else _v
-        _v = arg.pop('widthsrc', None)
-        self['widthsrc'] = widthsrc if widthsrc is not None else _v
+        _v = arg.pop("autocolorscale", None)
+        _v = autocolorscale if autocolorscale is not None else _v
+        if _v is not None:
+            self["autocolorscale"] = _v
+        _v = arg.pop("cauto", None)
+        _v = cauto if cauto is not None else _v
+        if _v is not None:
+            self["cauto"] = _v
+        _v = arg.pop("cmax", None)
+        _v = cmax if cmax is not None else _v
+        if _v is not None:
+            self["cmax"] = _v
+        _v = arg.pop("cmid", None)
+        _v = cmid if cmid is not None else _v
+        if _v is not None:
+            self["cmid"] = _v
+        _v = arg.pop("cmin", None)
+        _v = cmin if cmin is not None else _v
+        if _v is not None:
+            self["cmin"] = _v
+        _v = arg.pop("color", None)
+        _v = color if color is not None else _v
+        if _v is not None:
+            self["color"] = _v
+        _v = arg.pop("coloraxis", None)
+        _v = coloraxis if coloraxis is not None else _v
+        if _v is not None:
+            self["coloraxis"] = _v
+        _v = arg.pop("colorscale", None)
+        _v = colorscale if colorscale is not None else _v
+        if _v is not None:
+            self["colorscale"] = _v
+        _v = arg.pop("colorsrc", None)
+        _v = colorsrc if colorsrc is not None else _v
+        if _v is not None:
+            self["colorsrc"] = _v
+        _v = arg.pop("reversescale", None)
+        _v = reversescale if reversescale is not None else _v
+        if _v is not None:
+            self["reversescale"] = _v
+        _v = arg.pop("width", None)
+        _v = width if width is not None else _v
+        if _v is not None:
+            self["width"] = _v
+        _v = arg.pop("widthsrc", None)
+        _v = widthsrc if widthsrc is not None else _v
+        if _v is not None:
+            self["widthsrc"] = _v
 
         # Process unknown kwargs
         # ----------------------
