@@ -1,8 +1,103 @@
-from plotly.basedatatypes import BaseTraceHierarchyType
-import copy
+from plotly.basedatatypes import BaseTraceHierarchyType as _BaseTraceHierarchyType
+import copy as _copy
 
 
-class Marker(BaseTraceHierarchyType):
+class Marker(_BaseTraceHierarchyType):
+
+    # class properties
+    # --------------------
+    _parent_path_str = "scattermapbox"
+    _path_str = "scattermapbox.marker"
+    _valid_props = {
+        "allowoverlap",
+        "angle",
+        "anglesrc",
+        "autocolorscale",
+        "cauto",
+        "cmax",
+        "cmid",
+        "cmin",
+        "color",
+        "coloraxis",
+        "colorbar",
+        "colorscale",
+        "colorsrc",
+        "opacity",
+        "opacitysrc",
+        "reversescale",
+        "showscale",
+        "size",
+        "sizemin",
+        "sizemode",
+        "sizeref",
+        "sizesrc",
+        "symbol",
+        "symbolsrc",
+    }
+
+    # allowoverlap
+    # ------------
+    @property
+    def allowoverlap(self):
+        """
+        Flag to draw all symbols, even if they overlap.
+    
+        The 'allowoverlap' property must be specified as a bool
+        (either True, or False)
+
+        Returns
+        -------
+        bool
+        """
+        return self["allowoverlap"]
+
+    @allowoverlap.setter
+    def allowoverlap(self, val):
+        self["allowoverlap"] = val
+
+    # angle
+    # -----
+    @property
+    def angle(self):
+        """
+        Sets the marker orientation from true North, in degrees
+        clockwise. When using the "auto" default, no rotation would be
+        applied in perspective views which is different from using a
+        zero angle.
+    
+        The 'angle' property is a number and may be specified as:
+          - An int or float
+          - A tuple, list, or one-dimensional numpy array of the above
+
+        Returns
+        -------
+        int|float|numpy.ndarray
+        """
+        return self["angle"]
+
+    @angle.setter
+    def angle(self, val):
+        self["angle"] = val
+
+    # anglesrc
+    # --------
+    @property
+    def anglesrc(self):
+        """
+        Sets the source reference on Chart Studio Cloud for  angle .
+    
+        The 'anglesrc' property must be specified as a string or
+        as a plotly.grid_objs.Column object
+
+        Returns
+        -------
+        str
+        """
+        return self["anglesrc"]
+
+    @anglesrc.setter
+    def anglesrc(self, val):
+        self["anglesrc"] = val
 
     # autocolorscale
     # --------------
@@ -24,11 +119,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['autocolorscale']
+        return self["autocolorscale"]
 
     @autocolorscale.setter
     def autocolorscale(self, val):
-        self['autocolorscale'] = val
+        self["autocolorscale"] = val
 
     # cauto
     # -----
@@ -49,11 +144,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['cauto']
+        return self["cauto"]
 
     @cauto.setter
     def cauto(self, val):
-        self['cauto'] = val
+        self["cauto"] = val
 
     # cmax
     # ----
@@ -72,11 +167,35 @@ class Marker(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['cmax']
+        return self["cmax"]
 
     @cmax.setter
     def cmax(self, val):
-        self['cmax'] = val
+        self["cmax"] = val
+
+    # cmid
+    # ----
+    @property
+    def cmid(self):
+        """
+        Sets the mid-point of the color domain by scaling `marker.cmin`
+        and/or `marker.cmax` to be equidistant to this point. Has an
+        effect only if in `marker.color`is set to a numerical array.
+        Value should have the same units as in `marker.color`. Has no
+        effect when `marker.cauto` is `false`.
+    
+        The 'cmid' property is a number and may be specified as:
+          - An int or float
+
+        Returns
+        -------
+        int|float
+        """
+        return self["cmid"]
+
+    @cmid.setter
+    def cmid(self, val):
+        self["cmid"] = val
 
     # cmin
     # ----
@@ -95,11 +214,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['cmin']
+        return self["cmin"]
 
     @cmin.setter
     def cmin(self, val):
-        self['cmin'] = val
+        self["cmin"] = val
 
     # color
     # -----
@@ -146,12 +265,12 @@ class Marker(BaseTraceHierarchyType):
                 orchid, palegoldenrod, palegreen, paleturquoise,
                 palevioletred, papayawhip, peachpuff, peru, pink,
                 plum, powderblue, purple, red, rosybrown,
-                royalblue, saddlebrown, salmon, sandybrown,
-                seagreen, seashell, sienna, silver, skyblue,
-                slateblue, slategray, slategrey, snow, springgreen,
-                steelblue, tan, teal, thistle, tomato, turquoise,
-                violet, wheat, white, whitesmoke, yellow,
-                yellowgreen
+                royalblue, rebeccapurple, saddlebrown, salmon,
+                sandybrown, seagreen, seashell, sienna, silver,
+                skyblue, slateblue, slategray, slategrey, snow,
+                springgreen, steelblue, tan, teal, thistle, tomato,
+                turquoise, violet, wheat, white, whitesmoke,
+                yellow, yellowgreen
           - A number that will be interpreted as a color
             according to scattermapbox.marker.colorscale
           - A list or array of any of the above
@@ -160,11 +279,38 @@ class Marker(BaseTraceHierarchyType):
         -------
         str|numpy.ndarray
         """
-        return self['color']
+        return self["color"]
 
     @color.setter
     def color(self, val):
-        self['color'] = val
+        self["color"] = val
+
+    # coloraxis
+    # ---------
+    @property
+    def coloraxis(self):
+        """
+        Sets a reference to a shared color axis. References to these
+        shared color axes are "coloraxis", "coloraxis2", "coloraxis3",
+        etc. Settings for these shared color axes are set in the
+        layout, under `layout.coloraxis`, `layout.coloraxis2`, etc.
+        Note that multiple color scales can be linked to the same color
+        axis.
+    
+        The 'coloraxis' property is an identifier of a particular
+        subplot, of type 'coloraxis', that may be specified as the string 'coloraxis'
+        optionally followed by an integer >= 1
+        (e.g. 'coloraxis', 'coloraxis1', 'coloraxis2', 'coloraxis3', etc.)
+
+        Returns
+        -------
+        str
+        """
+        return self["coloraxis"]
+
+    @coloraxis.setter
+    def coloraxis(self, val):
+        self["coloraxis"] = val
 
     # colorbar
     # --------
@@ -173,7 +319,7 @@ class Marker(BaseTraceHierarchyType):
         """
         The 'colorbar' property is an instance of ColorBar
         that may be specified as:
-          - An instance of plotly.graph_objs.scattermapbox.marker.ColorBar
+          - An instance of :class:`plotly.graph_objs.scattermapbox.marker.ColorBar`
           - A dict of string/value properties that will be passed
             to the ColorBar constructor
     
@@ -293,20 +439,21 @@ class Marker(BaseTraceHierarchyType):
                 tickformat
                     Sets the tick label formatting rule using d3
                     formatting mini-languages which are very
-                    similar to those in Python. For numbers, see: h
-                    ttps://github.com/d3/d3-format/blob/master/READ
-                    ME.md#locale_format And for dates see:
-                    https://github.com/d3/d3-time-
-                    format/blob/master/README.md#locale_format We
-                    add one item to d3's date formatter: "%{n}f"
+                    similar to those in Python. For numbers, see:
+                    https://github.com/d3/d3-3.x-api-
+                    reference/blob/master/Formatting.md#d3_format
+                    And for dates see:
+                    https://github.com/d3/d3-3.x-api-
+                    reference/blob/master/Time-Formatting.md#format
+                    We add one item to d3's date formatter: "%{n}f"
                     for fractional seconds with n digits. For
                     example, *2016-10-13 09:15:23.456* with
                     tickformat "%H~%M~%S.%2f" would display
                     "09~15~23.46"
                 tickformatstops
-                    plotly.graph_objs.scattermapbox.marker.colorbar
-                    .Tickformatstop instance or dict with
-                    compatible properties
+                    A tuple of :class:`plotly.graph_objects.scatter
+                    mapbox.marker.colorbar.Tickformatstop`
+                    instances or dicts with compatible properties
                 tickformatstopdefaults
                     When used in a template (as layout.template.dat
                     a.scattermapbox.marker.colorbar.tickformatstopd
@@ -341,21 +488,21 @@ class Marker(BaseTraceHierarchyType):
                     `tickmode` is set to "array". Used with
                     `tickvals`.
                 ticktextsrc
-                    Sets the source reference on plot.ly for
-                    ticktext .
+                    Sets the source reference on Chart Studio Cloud
+                    for  ticktext .
                 tickvals
                     Sets the values at which ticks on this axis
                     appear. Only has an effect if `tickmode` is set
                     to "array". Used with `ticktext`.
                 tickvalssrc
-                    Sets the source reference on plot.ly for
-                    tickvals .
+                    Sets the source reference on Chart Studio Cloud
+                    for  tickvals .
                 tickwidth
                     Sets the tick width (in px).
                 title
-                    plotly.graph_objs.scattermapbox.marker.colorbar
-                    .Title instance or dict with compatible
-                    properties
+                    :class:`plotly.graph_objects.scattermapbox.mark
+                    er.colorbar.Title` instance or dict with
+                    compatible properties
                 titlefont
                     Deprecated: Please use
                     scattermapbox.marker.colorbar.title.font
@@ -395,11 +542,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         plotly.graph_objs.scattermapbox.marker.ColorBar
         """
-        return self['colorbar']
+        return self["colorbar"]
 
     @colorbar.setter
     def colorbar(self, val):
-        self['colorbar'] = val
+        self["colorbar"] = val
 
     # colorscale
     # ----------
@@ -411,7 +558,7 @@ class Marker(BaseTraceHierarchyType):
         containing arrays mapping a normalized value to an rgb, rgba,
         hex, hsl, hsv, or named color string. At minimum, a mapping for
         the lowest (0) and highest (1) values are required. For
-        example, `[[0, 'rgb(0,0,255)', [1, 'rgb(255,0,0)']]`. To
+        example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To
         control the bounds of the colorscale in color space,
         use`marker.cmin` and `marker.cmax`. Alternatively, `colorscale`
         may be a palette name string of the following list: Greys,YlGnB
@@ -420,31 +567,46 @@ class Marker(BaseTraceHierarchyType):
     
         The 'colorscale' property is a colorscale and may be
         specified as:
+          - A list of colors that will be spaced evenly to create the colorscale.
+            Many predefined colorscale lists are included in the sequential, diverging,
+            and cyclical modules in the plotly.colors package.
           - A list of 2-element lists where the first element is the
             normalized color level value (starting at 0 and ending at 1), 
             and the second item is a valid color string.
             (e.g. [[0, 'green'], [0.5, 'red'], [1.0, 'rgb(0, 0, 255)']])
           - One of the following named colorscales:
-                ['Greys', 'YlGnBu', 'Greens', 'YlOrRd', 'Bluered', 'RdBu',
-                'Reds', 'Blues', 'Picnic', 'Rainbow', 'Portland', 'Jet',
-                'Hot', 'Blackbody', 'Earth', 'Electric', 'Viridis', 'Cividis']
+                ['aggrnyl', 'agsunset', 'algae', 'amp', 'armyrose', 'balance',
+                 'blackbody', 'bluered', 'blues', 'blugrn', 'bluyl', 'brbg',
+                 'brwnyl', 'bugn', 'bupu', 'burg', 'burgyl', 'cividis', 'curl',
+                 'darkmint', 'deep', 'delta', 'dense', 'earth', 'edge', 'electric',
+                 'emrld', 'fall', 'geyser', 'gnbu', 'gray', 'greens', 'greys',
+                 'haline', 'hot', 'hsv', 'ice', 'icefire', 'inferno', 'jet',
+                 'magenta', 'magma', 'matter', 'mint', 'mrybm', 'mygbm', 'oranges',
+                 'orrd', 'oryel', 'peach', 'phase', 'picnic', 'pinkyl', 'piyg',
+                 'plasma', 'plotly3', 'portland', 'prgn', 'pubu', 'pubugn', 'puor',
+                 'purd', 'purp', 'purples', 'purpor', 'rainbow', 'rdbu', 'rdgy',
+                 'rdpu', 'rdylbu', 'rdylgn', 'redor', 'reds', 'solar', 'spectral',
+                 'speed', 'sunset', 'sunsetdark', 'teal', 'tealgrn', 'tealrose',
+                 'tempo', 'temps', 'thermal', 'tropic', 'turbid', 'twilight',
+                 'viridis', 'ylgn', 'ylgnbu', 'ylorbr', 'ylorrd'].
+            Appending '_r' to a named colorscale reverses it.
 
         Returns
         -------
         str
         """
-        return self['colorscale']
+        return self["colorscale"]
 
     @colorscale.setter
     def colorscale(self, val):
-        self['colorscale'] = val
+        self["colorscale"] = val
 
     # colorsrc
     # --------
     @property
     def colorsrc(self):
         """
-        Sets the source reference on plot.ly for  color .
+        Sets the source reference on Chart Studio Cloud for  color .
     
         The 'colorsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -453,11 +615,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['colorsrc']
+        return self["colorsrc"]
 
     @colorsrc.setter
     def colorsrc(self, val):
-        self['colorsrc'] = val
+        self["colorsrc"] = val
 
     # opacity
     # -------
@@ -474,18 +636,18 @@ class Marker(BaseTraceHierarchyType):
         -------
         int|float|numpy.ndarray
         """
-        return self['opacity']
+        return self["opacity"]
 
     @opacity.setter
     def opacity(self, val):
-        self['opacity'] = val
+        self["opacity"] = val
 
     # opacitysrc
     # ----------
     @property
     def opacitysrc(self):
         """
-        Sets the source reference on plot.ly for  opacity .
+        Sets the source reference on Chart Studio Cloud for  opacity .
     
         The 'opacitysrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -494,11 +656,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['opacitysrc']
+        return self["opacitysrc"]
 
     @opacitysrc.setter
     def opacitysrc(self, val):
-        self['opacitysrc'] = val
+        self["opacitysrc"] = val
 
     # reversescale
     # ------------
@@ -517,11 +679,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['reversescale']
+        return self["reversescale"]
 
     @reversescale.setter
     def reversescale(self, val):
-        self['reversescale'] = val
+        self["reversescale"] = val
 
     # showscale
     # ---------
@@ -539,11 +701,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         bool
         """
-        return self['showscale']
+        return self["showscale"]
 
     @showscale.setter
     def showscale(self, val):
-        self['showscale'] = val
+        self["showscale"] = val
 
     # size
     # ----
@@ -560,11 +722,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         int|float|numpy.ndarray
         """
-        return self['size']
+        return self["size"]
 
     @size.setter
     def size(self, val):
-        self['size'] = val
+        self["size"] = val
 
     # sizemin
     # -------
@@ -582,11 +744,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['sizemin']
+        return self["sizemin"]
 
     @sizemin.setter
     def sizemin(self, val):
-        self['sizemin'] = val
+        self["sizemin"] = val
 
     # sizemode
     # --------
@@ -605,11 +767,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         Any
         """
-        return self['sizemode']
+        return self["sizemode"]
 
     @sizemode.setter
     def sizemode(self, val):
-        self['sizemode'] = val
+        self["sizemode"] = val
 
     # sizeref
     # -------
@@ -627,18 +789,18 @@ class Marker(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['sizeref']
+        return self["sizeref"]
 
     @sizeref.setter
     def sizeref(self, val):
-        self['sizeref'] = val
+        self["sizeref"] = val
 
     # sizesrc
     # -------
     @property
     def sizesrc(self):
         """
-        Sets the source reference on plot.ly for  size .
+        Sets the source reference on Chart Studio Cloud for  size .
     
         The 'sizesrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -647,11 +809,11 @@ class Marker(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['sizesrc']
+        return self["sizesrc"]
 
     @sizesrc.setter
     def sizesrc(self, val):
-        self['sizesrc'] = val
+        self["sizesrc"] = val
 
     # symbol
     # ------
@@ -671,18 +833,18 @@ class Marker(BaseTraceHierarchyType):
         -------
         str|numpy.ndarray
         """
-        return self['symbol']
+        return self["symbol"]
 
     @symbol.setter
     def symbol(self, val):
-        self['symbol'] = val
+        self["symbol"] = val
 
     # symbolsrc
     # ---------
     @property
     def symbolsrc(self):
         """
-        Sets the source reference on plot.ly for  symbol .
+        Sets the source reference on Chart Studio Cloud for  symbol .
     
         The 'symbolsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -691,23 +853,27 @@ class Marker(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['symbolsrc']
+        return self["symbolsrc"]
 
     @symbolsrc.setter
     def symbolsrc(self, val):
-        self['symbolsrc'] = val
-
-    # property parent name
-    # --------------------
-    @property
-    def _parent_path_str(self):
-        return 'scattermapbox'
+        self["symbolsrc"] = val
 
     # Self properties description
     # ---------------------------
     @property
     def _prop_descriptions(self):
         return """\
+        allowoverlap
+            Flag to draw all symbols, even if they overlap.
+        angle
+            Sets the marker orientation from true North, in degrees
+            clockwise. When using the "auto" default, no rotation
+            would be applied in perspective views which is
+            different from using a zero angle.
+        anglesrc
+            Sets the source reference on Chart Studio Cloud for
+            angle .
         autocolorscale
             Determines whether the colorscale is a default palette
             (`autocolorscale: true`) or the palette determined by
@@ -729,6 +895,13 @@ class Marker(BaseTraceHierarchyType):
             only if in `marker.color`is set to a numerical array.
             Value should have the same units as in `marker.color`
             and if set, `marker.cmin` must be set as well.
+        cmid
+            Sets the mid-point of the color domain by scaling
+            `marker.cmin` and/or `marker.cmax` to be equidistant to
+            this point. Has an effect only if in `marker.color`is
+            set to a numerical array. Value should have the same
+            units as in `marker.color`. Has no effect when
+            `marker.cauto` is `false`.
         cmin
             Sets the lower bound of the color domain. Has an effect
             only if in `marker.color`is set to a numerical array.
@@ -740,9 +913,16 @@ class Marker(BaseTraceHierarchyType):
             colorscale relative to the max and min values of the
             array or relative to `marker.cmin` and `marker.cmax` if
             set.
+        coloraxis
+            Sets a reference to a shared color axis. References to
+            these shared color axes are "coloraxis", "coloraxis2",
+            "coloraxis3", etc. Settings for these shared color axes
+            are set in the layout, under `layout.coloraxis`,
+            `layout.coloraxis2`, etc. Note that multiple color
+            scales can be linked to the same color axis.
         colorbar
-            plotly.graph_objs.scattermapbox.marker.ColorBar
-            instance or dict with compatible properties
+            :class:`plotly.graph_objects.scattermapbox.marker.Color
+            Bar` instance or dict with compatible properties
         colorscale
             Sets the colorscale. Has an effect only if in
             `marker.color`is set to a numerical array. The
@@ -750,7 +930,7 @@ class Marker(BaseTraceHierarchyType):
             normalized value to an rgb, rgba, hex, hsl, hsv, or
             named color string. At minimum, a mapping for the
             lowest (0) and highest (1) values are required. For
-            example, `[[0, 'rgb(0,0,255)', [1, 'rgb(255,0,0)']]`.
+            example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`.
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
@@ -758,11 +938,13 @@ class Marker(BaseTraceHierarchyType):
             ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
             arth,Electric,Viridis,Cividis.
         colorsrc
-            Sets the source reference on plot.ly for  color .
+            Sets the source reference on Chart Studio Cloud for
+            color .
         opacity
             Sets the marker opacity.
         opacitysrc
-            Sets the source reference on plot.ly for  opacity .
+            Sets the source reference on Chart Studio Cloud for
+            opacity .
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.color`is set to a numerical array. If
@@ -789,24 +971,31 @@ class Marker(BaseTraceHierarchyType):
             determine the rendered size of marker points. Use with
             `sizemin` and `sizemode`.
         sizesrc
-            Sets the source reference on plot.ly for  size .
+            Sets the source reference on Chart Studio Cloud for
+            size .
         symbol
             Sets the marker symbol. Full list:
             https://www.mapbox.com/maki-icons/ Note that the array
             `marker.color` and `marker.size` are only available for
             "circle" symbols.
         symbolsrc
-            Sets the source reference on plot.ly for  symbol .
+            Sets the source reference on Chart Studio Cloud for
+            symbol .
         """
 
     def __init__(
         self,
         arg=None,
+        allowoverlap=None,
+        angle=None,
+        anglesrc=None,
         autocolorscale=None,
         cauto=None,
         cmax=None,
+        cmid=None,
         cmin=None,
         color=None,
+        coloraxis=None,
         colorbar=None,
         colorscale=None,
         colorsrc=None,
@@ -830,7 +1019,18 @@ class Marker(BaseTraceHierarchyType):
         ----------
         arg
             dict of properties compatible with this constructor or
-            an instance of plotly.graph_objs.scattermapbox.Marker
+            an instance of
+            :class:`plotly.graph_objs.scattermapbox.Marker`
+        allowoverlap
+            Flag to draw all symbols, even if they overlap.
+        angle
+            Sets the marker orientation from true North, in degrees
+            clockwise. When using the "auto" default, no rotation
+            would be applied in perspective views which is
+            different from using a zero angle.
+        anglesrc
+            Sets the source reference on Chart Studio Cloud for
+            angle .
         autocolorscale
             Determines whether the colorscale is a default palette
             (`autocolorscale: true`) or the palette determined by
@@ -852,6 +1052,13 @@ class Marker(BaseTraceHierarchyType):
             only if in `marker.color`is set to a numerical array.
             Value should have the same units as in `marker.color`
             and if set, `marker.cmin` must be set as well.
+        cmid
+            Sets the mid-point of the color domain by scaling
+            `marker.cmin` and/or `marker.cmax` to be equidistant to
+            this point. Has an effect only if in `marker.color`is
+            set to a numerical array. Value should have the same
+            units as in `marker.color`. Has no effect when
+            `marker.cauto` is `false`.
         cmin
             Sets the lower bound of the color domain. Has an effect
             only if in `marker.color`is set to a numerical array.
@@ -863,9 +1070,16 @@ class Marker(BaseTraceHierarchyType):
             colorscale relative to the max and min values of the
             array or relative to `marker.cmin` and `marker.cmax` if
             set.
+        coloraxis
+            Sets a reference to a shared color axis. References to
+            these shared color axes are "coloraxis", "coloraxis2",
+            "coloraxis3", etc. Settings for these shared color axes
+            are set in the layout, under `layout.coloraxis`,
+            `layout.coloraxis2`, etc. Note that multiple color
+            scales can be linked to the same color axis.
         colorbar
-            plotly.graph_objs.scattermapbox.marker.ColorBar
-            instance or dict with compatible properties
+            :class:`plotly.graph_objects.scattermapbox.marker.Color
+            Bar` instance or dict with compatible properties
         colorscale
             Sets the colorscale. Has an effect only if in
             `marker.color`is set to a numerical array. The
@@ -873,7 +1087,7 @@ class Marker(BaseTraceHierarchyType):
             normalized value to an rgb, rgba, hex, hsl, hsv, or
             named color string. At minimum, a mapping for the
             lowest (0) and highest (1) values are required. For
-            example, `[[0, 'rgb(0,0,255)', [1, 'rgb(255,0,0)']]`.
+            example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`.
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
@@ -881,11 +1095,13 @@ class Marker(BaseTraceHierarchyType):
             ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
             arth,Electric,Viridis,Cividis.
         colorsrc
-            Sets the source reference on plot.ly for  color .
+            Sets the source reference on Chart Studio Cloud for
+            color .
         opacity
             Sets the marker opacity.
         opacitysrc
-            Sets the source reference on plot.ly for  opacity .
+            Sets the source reference on Chart Studio Cloud for
+            opacity .
         reversescale
             Reverses the color mapping if true. Has an effect only
             if in `marker.color`is set to a numerical array. If
@@ -912,20 +1128,26 @@ class Marker(BaseTraceHierarchyType):
             determine the rendered size of marker points. Use with
             `sizemin` and `sizemode`.
         sizesrc
-            Sets the source reference on plot.ly for  size .
+            Sets the source reference on Chart Studio Cloud for
+            size .
         symbol
             Sets the marker symbol. Full list:
             https://www.mapbox.com/maki-icons/ Note that the array
             `marker.color` and `marker.size` are only available for
             "circle" symbols.
         symbolsrc
-            Sets the source reference on plot.ly for  symbol .
+            Sets the source reference on Chart Studio Cloud for
+            symbol .
 
         Returns
         -------
         Marker
         """
-        super(Marker, self).__init__('marker')
+        super(Marker, self).__init__("marker")
+
+        if "_parent" in kwargs:
+            self._parent = kwargs["_parent"]
+            return
 
         # Validate arg
         # ------------
@@ -934,86 +1156,118 @@ class Marker(BaseTraceHierarchyType):
         elif isinstance(arg, self.__class__):
             arg = arg.to_plotly_json()
         elif isinstance(arg, dict):
-            arg = copy.copy(arg)
+            arg = _copy.copy(arg)
         else:
             raise ValueError(
                 """\
 The first argument to the plotly.graph_objs.scattermapbox.Marker 
 constructor must be a dict or 
-an instance of plotly.graph_objs.scattermapbox.Marker"""
+an instance of :class:`plotly.graph_objs.scattermapbox.Marker`"""
             )
 
         # Handle skip_invalid
         # -------------------
-        self._skip_invalid = kwargs.pop('skip_invalid', False)
-
-        # Import validators
-        # -----------------
-        from plotly.validators.scattermapbox import (marker as v_marker)
-
-        # Initialize validators
-        # ---------------------
-        self._validators['autocolorscale'] = v_marker.AutocolorscaleValidator()
-        self._validators['cauto'] = v_marker.CautoValidator()
-        self._validators['cmax'] = v_marker.CmaxValidator()
-        self._validators['cmin'] = v_marker.CminValidator()
-        self._validators['color'] = v_marker.ColorValidator()
-        self._validators['colorbar'] = v_marker.ColorBarValidator()
-        self._validators['colorscale'] = v_marker.ColorscaleValidator()
-        self._validators['colorsrc'] = v_marker.ColorsrcValidator()
-        self._validators['opacity'] = v_marker.OpacityValidator()
-        self._validators['opacitysrc'] = v_marker.OpacitysrcValidator()
-        self._validators['reversescale'] = v_marker.ReversescaleValidator()
-        self._validators['showscale'] = v_marker.ShowscaleValidator()
-        self._validators['size'] = v_marker.SizeValidator()
-        self._validators['sizemin'] = v_marker.SizeminValidator()
-        self._validators['sizemode'] = v_marker.SizemodeValidator()
-        self._validators['sizeref'] = v_marker.SizerefValidator()
-        self._validators['sizesrc'] = v_marker.SizesrcValidator()
-        self._validators['symbol'] = v_marker.SymbolValidator()
-        self._validators['symbolsrc'] = v_marker.SymbolsrcValidator()
+        self._skip_invalid = kwargs.pop("skip_invalid", False)
+        self._validate = kwargs.pop("_validate", True)
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop('autocolorscale', None)
-        self['autocolorscale'
-            ] = autocolorscale if autocolorscale is not None else _v
-        _v = arg.pop('cauto', None)
-        self['cauto'] = cauto if cauto is not None else _v
-        _v = arg.pop('cmax', None)
-        self['cmax'] = cmax if cmax is not None else _v
-        _v = arg.pop('cmin', None)
-        self['cmin'] = cmin if cmin is not None else _v
-        _v = arg.pop('color', None)
-        self['color'] = color if color is not None else _v
-        _v = arg.pop('colorbar', None)
-        self['colorbar'] = colorbar if colorbar is not None else _v
-        _v = arg.pop('colorscale', None)
-        self['colorscale'] = colorscale if colorscale is not None else _v
-        _v = arg.pop('colorsrc', None)
-        self['colorsrc'] = colorsrc if colorsrc is not None else _v
-        _v = arg.pop('opacity', None)
-        self['opacity'] = opacity if opacity is not None else _v
-        _v = arg.pop('opacitysrc', None)
-        self['opacitysrc'] = opacitysrc if opacitysrc is not None else _v
-        _v = arg.pop('reversescale', None)
-        self['reversescale'] = reversescale if reversescale is not None else _v
-        _v = arg.pop('showscale', None)
-        self['showscale'] = showscale if showscale is not None else _v
-        _v = arg.pop('size', None)
-        self['size'] = size if size is not None else _v
-        _v = arg.pop('sizemin', None)
-        self['sizemin'] = sizemin if sizemin is not None else _v
-        _v = arg.pop('sizemode', None)
-        self['sizemode'] = sizemode if sizemode is not None else _v
-        _v = arg.pop('sizeref', None)
-        self['sizeref'] = sizeref if sizeref is not None else _v
-        _v = arg.pop('sizesrc', None)
-        self['sizesrc'] = sizesrc if sizesrc is not None else _v
-        _v = arg.pop('symbol', None)
-        self['symbol'] = symbol if symbol is not None else _v
-        _v = arg.pop('symbolsrc', None)
-        self['symbolsrc'] = symbolsrc if symbolsrc is not None else _v
+        _v = arg.pop("allowoverlap", None)
+        _v = allowoverlap if allowoverlap is not None else _v
+        if _v is not None:
+            self["allowoverlap"] = _v
+        _v = arg.pop("angle", None)
+        _v = angle if angle is not None else _v
+        if _v is not None:
+            self["angle"] = _v
+        _v = arg.pop("anglesrc", None)
+        _v = anglesrc if anglesrc is not None else _v
+        if _v is not None:
+            self["anglesrc"] = _v
+        _v = arg.pop("autocolorscale", None)
+        _v = autocolorscale if autocolorscale is not None else _v
+        if _v is not None:
+            self["autocolorscale"] = _v
+        _v = arg.pop("cauto", None)
+        _v = cauto if cauto is not None else _v
+        if _v is not None:
+            self["cauto"] = _v
+        _v = arg.pop("cmax", None)
+        _v = cmax if cmax is not None else _v
+        if _v is not None:
+            self["cmax"] = _v
+        _v = arg.pop("cmid", None)
+        _v = cmid if cmid is not None else _v
+        if _v is not None:
+            self["cmid"] = _v
+        _v = arg.pop("cmin", None)
+        _v = cmin if cmin is not None else _v
+        if _v is not None:
+            self["cmin"] = _v
+        _v = arg.pop("color", None)
+        _v = color if color is not None else _v
+        if _v is not None:
+            self["color"] = _v
+        _v = arg.pop("coloraxis", None)
+        _v = coloraxis if coloraxis is not None else _v
+        if _v is not None:
+            self["coloraxis"] = _v
+        _v = arg.pop("colorbar", None)
+        _v = colorbar if colorbar is not None else _v
+        if _v is not None:
+            self["colorbar"] = _v
+        _v = arg.pop("colorscale", None)
+        _v = colorscale if colorscale is not None else _v
+        if _v is not None:
+            self["colorscale"] = _v
+        _v = arg.pop("colorsrc", None)
+        _v = colorsrc if colorsrc is not None else _v
+        if _v is not None:
+            self["colorsrc"] = _v
+        _v = arg.pop("opacity", None)
+        _v = opacity if opacity is not None else _v
+        if _v is not None:
+            self["opacity"] = _v
+        _v = arg.pop("opacitysrc", None)
+        _v = opacitysrc if opacitysrc is not None else _v
+        if _v is not None:
+            self["opacitysrc"] = _v
+        _v = arg.pop("reversescale", None)
+        _v = reversescale if reversescale is not None else _v
+        if _v is not None:
+            self["reversescale"] = _v
+        _v = arg.pop("showscale", None)
+        _v = showscale if showscale is not None else _v
+        if _v is not None:
+            self["showscale"] = _v
+        _v = arg.pop("size", None)
+        _v = size if size is not None else _v
+        if _v is not None:
+            self["size"] = _v
+        _v = arg.pop("sizemin", None)
+        _v = sizemin if sizemin is not None else _v
+        if _v is not None:
+            self["sizemin"] = _v
+        _v = arg.pop("sizemode", None)
+        _v = sizemode if sizemode is not None else _v
+        if _v is not None:
+            self["sizemode"] = _v
+        _v = arg.pop("sizeref", None)
+        _v = sizeref if sizeref is not None else _v
+        if _v is not None:
+            self["sizeref"] = _v
+        _v = arg.pop("sizesrc", None)
+        _v = sizesrc if sizesrc is not None else _v
+        if _v is not None:
+            self["sizesrc"] = _v
+        _v = arg.pop("symbol", None)
+        _v = symbol if symbol is not None else _v
+        if _v is not None:
+            self["symbol"] = _v
+        _v = arg.pop("symbolsrc", None)
+        _v = symbolsrc if symbolsrc is not None else _v
+        if _v is not None:
+            self["symbolsrc"] = _v
 
         # Process unknown kwargs
         # ----------------------
