@@ -2,14 +2,20 @@ import _plotly_utils.basevalidators
 
 
 class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
-
-    def __init__(self, plotly_name='histogram', parent_name='', **kwargs):
+    def __init__(self, plotly_name="histogram", parent_name="", **kwargs):
         super(HistogramValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'Histogram'),
+            data_class_str=kwargs.pop("data_class_str", "Histogram"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
+            alignmentgroup
+                Set several traces linked to the same position
+                axis or matching axes to the same
+                alignmentgroup. This controls whether bars
+                compute their positional range dependently or
+                independently.
             autobinx
                 Obsolete: since v1.42 each bin attribute is
                 auto-determined separately and `autobinx` is
@@ -22,9 +28,20 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 not needed. However, we accept `autobiny: true`
                 or `false` and will update `ybins` accordingly
                 before deleting `autobiny` from the trace.
+            bingroup
+                Set a group of histogram traces which will have
+                compatible bin settings. Note that traces on
+                the same subplot and with the same
+                "orientation" under `barmode` "stack",
+                "relative" and "group" are forced into the same
+                bingroup, Using `bingroup`, traces under
+                `barmode` "overlay" and on different axes (of
+                the same axis type) can have compatible bin
+                settings. Note that histogram and histogram2d*
+                trace can share the same `bingroup`
             cumulative
-                plotly.graph_objs.histogram.Cumulative instance
-                or dict with compatible properties
+                :class:`plotly.graph_objects.histogram.Cumulati
+                ve` instance or dict with compatible properties
             customdata
                 Assigns extra data each datum. This may be
                 useful when listening to hover, click and
@@ -32,14 +49,14 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 also appends customdata items in the markers
                 DOM elements
             customdatasrc
-                Sets the source reference on plot.ly for
-                customdata .
+                Sets the source reference on Chart Studio Cloud
+                for  customdata .
             error_x
-                plotly.graph_objs.histogram.ErrorX instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.histogram.ErrorX`
+                instance or dict with compatible properties
             error_y
-                plotly.graph_objs.histogram.ErrorY instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.histogram.ErrorY`
+                instance or dict with compatible properties
             histfunc
                 Specifies the binning function used for this
                 histogram trace. If "count", the histogram
@@ -74,11 +91,11 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `none` is set, click and hover events are still
                 fired.
             hoverinfosrc
-                Sets the source reference on plot.ly for
-                hoverinfo .
+                Sets the source reference on Chart Studio Cloud
+                for  hoverinfo .
             hoverlabel
-                plotly.graph_objs.histogram.Hoverlabel instance
-                or dict with compatible properties
+                :class:`plotly.graph_objects.histogram.Hoverlab
+                el` instance or dict with compatible properties
             hovertemplate
                 Template string used for rendering the
                 information that appear on hover box. Note that
@@ -86,35 +103,67 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 inserted using %{variable}, for example "y:
                 %{y}". Numbers are formatted using d3-format's
                 syntax %{variable:d3-format}, for example
-                "Price: %{y:$.2f}". See https://github.com/d3/d
-                3-format/blob/master/README.md#locale_format
-                for details on the formatting syntax. The
+                "Price: %{y:$.2f}".
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                for details on the formatting syntax. Dates are
+                formatted using d3-time-format's syntax
+                %{variable|d3-time-format}, for example "Day:
+                %{2019-01-01|%A}".
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                for details on the date formatting syntax. The
                 variables available in `hovertemplate` are the
                 ones emitted as event data described at this
-                link https://plot.ly/javascript/plotlyjs-
+                link https://plotly.com/javascript/plotlyjs-
                 events/#event-data. Additionally, every
                 attributes that can be specified per-point (the
                 ones that are `arrayOk: true`) are available.
                 variable `binNumber` Anything contained in tag
                 `<extra>` is displayed in the secondary box,
                 for example "<extra>{fullData.name}</extra>".
+                To hide the secondary box completely, use an
+                empty tag `<extra></extra>`.
             hovertemplatesrc
-                Sets the source reference on plot.ly for
-                hovertemplate .
+                Sets the source reference on Chart Studio Cloud
+                for  hovertemplate .
+            hovertext
+                Same as `text`.
+            hovertextsrc
+                Sets the source reference on Chart Studio Cloud
+                for  hovertext .
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
                 animation. Should be an array of strings, not
                 numbers or any other type.
             idssrc
-                Sets the source reference on plot.ly for  ids .
+                Sets the source reference on Chart Studio Cloud
+                for  ids .
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
                 same time when toggling legend items.
             marker
-                plotly.graph_objs.histogram.Marker instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.histogram.Marker`
+                instance or dict with compatible properties
+            meta
+                Assigns extra meta information associated with
+                this trace that can be used in various text
+                attributes. Attributes such as trace `name`,
+                graph, axis and colorbar `title.text`,
+                annotation `text` `rangeselector`,
+                `updatemenues` and `sliders` `label` text all
+                support `meta`. To access the trace `meta`
+                values in an attribute in the same trace,
+                simply use `%{meta[i]}` where `i` is the index
+                or key of the `meta` item in question. To
+                access trace `meta` in layout attributes, use
+                `%{data[n[.meta[i]}` where `i` is the index or
+                key of the `meta` and `n` is the trace index.
+            metasrc
+                Sets the source reference on Chart Studio Cloud
+                for  meta .
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -130,6 +179,11 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 will decide the optimal bin size such that the
                 histogram best visualizes the distribution of
                 the data. Ignored if `ybins.size` is provided.
+            offsetgroup
+                Set several traces linked to the same position
+                axis or matching axes to the same offsetgroup
+                where bars of the same position coordinate will
+                line up.
             opacity
                 Sets the opacity of the trace.
             orientation
@@ -137,8 +191,8 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 ("h"), the value of the each bar spans along
                 the vertical (horizontal).
             selected
-                plotly.graph_objs.histogram.Selected instance
-                or dict with compatible properties
+                :class:`plotly.graph_objects.histogram.Selected
+                ` instance or dict with compatible properties
             selectedpoints
                 Array containing integer indices of selected
                 points. Has an effect only for traces that
@@ -152,20 +206,17 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Determines whether or not an item corresponding
                 to this trace is shown in the legend.
             stream
-                plotly.graph_objs.histogram.Stream instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.histogram.Stream`
+                instance or dict with compatible properties
             text
-                Sets text elements associated with each (x,y)
-                pair. If a single string, the same string
-                appears over all the data points. If an array
-                of string, the items are mapped in order to the
-                this trace's (x,y) coordinates. If trace
-                `hoverinfo` contains a "text" flag and
-                "hovertext" is not set, these elements will be
-                seen in the hover labels.
+                Sets hover text elements associated with each
+                bar. If a single string, the same string
+                appears over all bars. If an array of string,
+                the items are mapped in order to the this
+                trace's coordinates.
             textsrc
-                Sets the source reference on plot.ly for  text
-                .
+                Sets the source reference on Chart Studio Cloud
+                for  text .
             uid
                 Assign an id to this trace, Use this to provide
                 object constancy between traces during
@@ -193,8 +244,8 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 driven changes if you give each trace a `uid`
                 that stays with it as it moves.
             unselected
-                plotly.graph_objs.histogram.Unselected instance
-                or dict with compatible properties
+                :class:`plotly.graph_objects.histogram.Unselect
+                ed` instance or dict with compatible properties
             visible
                 Determines whether or not this trace is
                 visible. If "legendonly", the trace is not
@@ -210,13 +261,14 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `layout.xaxis`. If "x2", the x coordinates
                 refer to `layout.xaxis2`, and so on.
             xbins
-                plotly.graph_objs.histogram.XBins instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.histogram.XBins`
+                instance or dict with compatible properties
             xcalendar
                 Sets the calendar system to use with `x` date
                 data.
             xsrc
-                Sets the source reference on plot.ly for  x .
+                Sets the source reference on Chart Studio Cloud
+                for  x .
             y
                 Sets the sample data to be binned on the y
                 axis.
@@ -227,14 +279,15 @@ class HistogramValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `layout.yaxis`. If "y2", the y coordinates
                 refer to `layout.yaxis2`, and so on.
             ybins
-                plotly.graph_objs.histogram.YBins instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.histogram.YBins`
+                instance or dict with compatible properties
             ycalendar
                 Sets the calendar system to use with `y` date
                 data.
             ysrc
-                Sets the source reference on plot.ly for  y .
-"""
+                Sets the source reference on Chart Studio Cloud
+                for  y .
+""",
             ),
             **kwargs
         )
