@@ -2,14 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class ParcatsValidator(_plotly_utils.basevalidators.CompoundValidator):
-
-    def __init__(self, plotly_name='parcats', parent_name='', **kwargs):
+    def __init__(self, plotly_name="parcats", parent_name="", **kwargs):
         super(ParcatsValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'Parcats'),
+            data_class_str=kwargs.pop("data_class_str", "Parcats"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
             arrangement
                 Sets the drag interaction mode for categories
                 and dimensions. If `perpendicular`, the
@@ -26,8 +26,8 @@ class ParcatsValidator(_plotly_utils.basevalidators.CompoundValidator):
                 state. Defaults to 1 so that each state
                 represents one observation
             countssrc
-                Sets the source reference on plot.ly for
-                counts .
+                Sets the source reference on Chart Studio Cloud
+                for  counts .
             dimensions
                 The dimensions (variables) of the parallel
                 categories diagram.
@@ -37,8 +37,8 @@ class ParcatsValidator(_plotly_utils.basevalidators.CompoundValidator):
                 property values to use for elements of
                 parcats.dimensions
             domain
-                plotly.graph_objs.parcats.Domain instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.parcats.Domain`
+                instance or dict with compatible properties
             hoverinfo
                 Determines which trace information appear on
                 hover. If `none` or `skip` are set, no
@@ -52,11 +52,58 @@ class ParcatsValidator(_plotly_utils.basevalidators.CompoundValidator):
                 interactions take place per color per category.
                 If `dimension`, hover interactions take place
                 across all categories per dimension.
+            hovertemplate
+                Template string used for rendering the
+                information that appear on hover box. Note that
+                this will override `hoverinfo`. Variables are
+                inserted using %{variable}, for example "y:
+                %{y}". Numbers are formatted using d3-format's
+                syntax %{variable:d3-format}, for example
+                "Price: %{y:$.2f}".
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                for details on the formatting syntax. Dates are
+                formatted using d3-time-format's syntax
+                %{variable|d3-time-format}, for example "Day:
+                %{2019-01-01|%A}".
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                for details on the date formatting syntax. The
+                variables available in `hovertemplate` are the
+                ones emitted as event data described at this
+                link https://plotly.com/javascript/plotlyjs-
+                events/#event-data. Additionally, every
+                attributes that can be specified per-point (the
+                ones that are `arrayOk: true`) are available.
+                variables `count`, `probability`, `category`,
+                `categorycount`, `colorcount` and
+                `bandcolorcount`. Anything contained in tag
+                `<extra>` is displayed in the secondary box,
+                for example "<extra>{fullData.name}</extra>".
+                To hide the secondary box completely, use an
+                empty tag `<extra></extra>`.
             labelfont
                 Sets the font for the `dimension` labels.
             line
-                plotly.graph_objs.parcats.Line instance or dict
-                with compatible properties
+                :class:`plotly.graph_objects.parcats.Line`
+                instance or dict with compatible properties
+            meta
+                Assigns extra meta information associated with
+                this trace that can be used in various text
+                attributes. Attributes such as trace `name`,
+                graph, axis and colorbar `title.text`,
+                annotation `text` `rangeselector`,
+                `updatemenues` and `sliders` `label` text all
+                support `meta`. To access the trace `meta`
+                values in an attribute in the same trace,
+                simply use `%{meta[i]}` where `i` is the index
+                or key of the `meta` item in question. To
+                access trace `meta` in layout attributes, use
+                `%{data[n[.meta[i]}` where `i` is the index or
+                key of the `meta` and `n` is the trace index.
+            metasrc
+                Sets the source reference on Chart Studio Cloud
+                for  meta .
             name
                 Sets the trace name. The trace name appear as
                 the legend item and on hover.
@@ -66,8 +113,8 @@ class ParcatsValidator(_plotly_utils.basevalidators.CompoundValidator):
                 left to right. If `backward`, sort paths based
                 on dimensions categories from right to left.
             stream
-                plotly.graph_objs.parcats.Stream instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.parcats.Stream`
+                instance or dict with compatible properties
             tickfont
                 Sets the font for the `category` labels.
             uid
@@ -101,7 +148,7 @@ class ParcatsValidator(_plotly_utils.basevalidators.CompoundValidator):
                 visible. If "legendonly", the trace is not
                 drawn, but can appear as a legend item
                 (provided that the legend itself is visible).
-"""
+""",
             ),
             **kwargs
         )
