@@ -2,14 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
-
-    def __init__(self, plotly_name='scatterpolar', parent_name='', **kwargs):
+    def __init__(self, plotly_name="scatterpolar", parent_name="", **kwargs):
         super(ScatterpolarValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'Scatterpolar'),
+            data_class_str=kwargs.pop("data_class_str", "Scatterpolar"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
             cliponaxis
                 Determines whether or not markers and text
                 nodes are clipped about the subplot axes. To
@@ -27,8 +27,8 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 also appends customdata items in the markers
                 DOM elements
             customdatasrc
-                Sets the source reference on plot.ly for
-                customdata .
+                Sets the source reference on Chart Studio Cloud
+                for  customdata .
             dr
                 Sets the r coordinate step.
             dtheta
@@ -59,11 +59,12 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `none` is set, click and hover events are still
                 fired.
             hoverinfosrc
-                Sets the source reference on plot.ly for
-                hoverinfo .
+                Sets the source reference on Chart Studio Cloud
+                for  hoverinfo .
             hoverlabel
-                plotly.graph_objs.scatterpolar.Hoverlabel
-                instance or dict with compatible properties
+                :class:`plotly.graph_objects.scatterpolar.Hover
+                label` instance or dict with compatible
+                properties
             hoveron
                 Do the hover effects highlight individual
                 points (markers or line points) or do they
@@ -78,21 +79,30 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 inserted using %{variable}, for example "y:
                 %{y}". Numbers are formatted using d3-format's
                 syntax %{variable:d3-format}, for example
-                "Price: %{y:$.2f}". See https://github.com/d3/d
-                3-format/blob/master/README.md#locale_format
-                for details on the formatting syntax. The
+                "Price: %{y:$.2f}".
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                for details on the formatting syntax. Dates are
+                formatted using d3-time-format's syntax
+                %{variable|d3-time-format}, for example "Day:
+                %{2019-01-01|%A}".
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                for details on the date formatting syntax. The
                 variables available in `hovertemplate` are the
                 ones emitted as event data described at this
-                link https://plot.ly/javascript/plotlyjs-
+                link https://plotly.com/javascript/plotlyjs-
                 events/#event-data. Additionally, every
                 attributes that can be specified per-point (the
                 ones that are `arrayOk: true`) are available.
                 Anything contained in tag `<extra>` is
                 displayed in the secondary box, for example
-                "<extra>{fullData.name}</extra>".
+                "<extra>{fullData.name}</extra>". To hide the
+                secondary box completely, use an empty tag
+                `<extra></extra>`.
             hovertemplatesrc
-                Sets the source reference on plot.ly for
-                hovertemplate .
+                Sets the source reference on Chart Studio Cloud
+                for  hovertemplate .
             hovertext
                 Sets hover text elements associated with each
                 (x,y) pair. If a single string, the same string
@@ -101,25 +111,43 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 this trace's (x,y) coordinates. To be seen,
                 trace `hoverinfo` must contain a "text" flag.
             hovertextsrc
-                Sets the source reference on plot.ly for
-                hovertext .
+                Sets the source reference on Chart Studio Cloud
+                for  hovertext .
             ids
                 Assigns id labels to each datum. These ids for
                 object constancy of data points during
                 animation. Should be an array of strings, not
                 numbers or any other type.
             idssrc
-                Sets the source reference on plot.ly for  ids .
+                Sets the source reference on Chart Studio Cloud
+                for  ids .
             legendgroup
                 Sets the legend group for this trace. Traces
                 part of the same legend group hide/show at the
                 same time when toggling legend items.
             line
-                plotly.graph_objs.scatterpolar.Line instance or
-                dict with compatible properties
+                :class:`plotly.graph_objects.scatterpolar.Line`
+                instance or dict with compatible properties
             marker
-                plotly.graph_objs.scatterpolar.Marker instance
-                or dict with compatible properties
+                :class:`plotly.graph_objects.scatterpolar.Marke
+                r` instance or dict with compatible properties
+            meta
+                Assigns extra meta information associated with
+                this trace that can be used in various text
+                attributes. Attributes such as trace `name`,
+                graph, axis and colorbar `title.text`,
+                annotation `text` `rangeselector`,
+                `updatemenues` and `sliders` `label` text all
+                support `meta`. To access the trace `meta`
+                values in an attribute in the same trace,
+                simply use `%{meta[i]}` where `i` is the index
+                or key of the `meta` item in question. To
+                access trace `meta` in layout attributes, use
+                `%{data[n[.meta[i]}` where `i` is the index or
+                key of the `meta` and `n` is the trace index.
+            metasrc
+                Sets the source reference on Chart Studio Cloud
+                for  meta .
             mode
                 Determines the drawing mode for this scatter
                 trace. If the provided `mode` includes "text"
@@ -140,10 +168,12 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 coordinates. Use with `dr` where `r0` is the
                 starting coordinate and `dr` the step.
             rsrc
-                Sets the source reference on plot.ly for  r .
+                Sets the source reference on Chart Studio Cloud
+                for  r .
             selected
-                plotly.graph_objs.scatterpolar.Selected
-                instance or dict with compatible properties
+                :class:`plotly.graph_objects.scatterpolar.Selec
+                ted` instance or dict with compatible
+                properties
             selectedpoints
                 Array containing integer indices of selected
                 points. Has an effect only for traces that
@@ -157,8 +187,8 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Determines whether or not an item corresponding
                 to this trace is shown in the legend.
             stream
-                plotly.graph_objs.scatterpolar.Stream instance
-                or dict with compatible properties
+                :class:`plotly.graph_objects.scatterpolar.Strea
+                m` instance or dict with compatible properties
             subplot
                 Sets a reference between this trace's data
                 coordinates and a polar subplot. If "polar"
@@ -180,11 +210,34 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the positions of the `text` elements with
                 respects to the (x,y) coordinates.
             textpositionsrc
-                Sets the source reference on plot.ly for
-                textposition .
+                Sets the source reference on Chart Studio Cloud
+                for  textposition .
             textsrc
-                Sets the source reference on plot.ly for  text
-                .
+                Sets the source reference on Chart Studio Cloud
+                for  text .
+            texttemplate
+                Template string used for rendering the
+                information text that appear on points. Note
+                that this will override `textinfo`. Variables
+                are inserted using %{variable}, for example "y:
+                %{y}". Numbers are formatted using d3-format's
+                syntax %{variable:d3-format}, for example
+                "Price: %{y:$.2f}".
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                for details on the formatting syntax. Dates are
+                formatted using d3-time-format's syntax
+                %{variable|d3-time-format}, for example "Day:
+                %{2019-01-01|%A}".
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                for details on the date formatting syntax.
+                Every attributes that can be specified per-
+                point (the ones that are `arrayOk: true`) are
+                available. variables `r`, `theta` and `text`.
+            texttemplatesrc
+                Sets the source reference on Chart Studio Cloud
+                for  texttemplate .
             theta
                 Sets the angular coordinates
             theta0
@@ -193,8 +246,8 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `theta0` is the starting coordinate and
                 `dtheta` the step.
             thetasrc
-                Sets the source reference on plot.ly for  theta
-                .
+                Sets the source reference on Chart Studio Cloud
+                for  theta .
             thetaunit
                 Sets the unit of input "theta" values. Has an
                 effect only when on "linear" angular axes.
@@ -225,14 +278,15 @@ class ScatterpolarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 driven changes if you give each trace a `uid`
                 that stays with it as it moves.
             unselected
-                plotly.graph_objs.scatterpolar.Unselected
-                instance or dict with compatible properties
+                :class:`plotly.graph_objects.scatterpolar.Unsel
+                ected` instance or dict with compatible
+                properties
             visible
                 Determines whether or not this trace is
                 visible. If "legendonly", the trace is not
                 drawn, but can appear as a legend item
                 (provided that the legend itself is visible).
-"""
+""",
             ),
             **kwargs
         )
