@@ -2,18 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class LenmodeValidator(_plotly_utils.basevalidators.EnumeratedValidator):
-
     def __init__(
-        self,
-        plotly_name='lenmode',
-        parent_name='bar.marker.colorbar',
-        **kwargs
+        self, plotly_name="lenmode", parent_name="bar.marker.colorbar", **kwargs
     ):
         super(LenmodeValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'info'),
-            values=kwargs.pop('values', ['fraction', 'pixels']),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            role=kwargs.pop("role", "info"),
+            values=kwargs.pop("values", ["fraction", "pixels"]),
             **kwargs
         )
