@@ -2,17 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class ShowticklabelsValidator(_plotly_utils.basevalidators.BooleanValidator):
-
     def __init__(
-        self,
-        plotly_name='showticklabels',
-        parent_name='contour.colorbar',
-        **kwargs
+        self, plotly_name="showticklabels", parent_name="contour.colorbar", **kwargs
     ):
         super(ShowticklabelsValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            role=kwargs.pop("role", "style"),
             **kwargs
         )
