@@ -2,17 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class ValueValidator(_plotly_utils.basevalidators.AnyValidator):
-
     def __init__(
-        self,
-        plotly_name='value',
-        parent_name='contourcarpet.contours',
-        **kwargs
+        self, plotly_name="value", parent_name="contourcarpet.contours", **kwargs
     ):
         super(ValueValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "calc"),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
