@@ -2,18 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class TracerefminusValidator(_plotly_utils.basevalidators.IntegerValidator):
-
     def __init__(
-        self,
-        plotly_name='tracerefminus',
-        parent_name='histogram.error_x',
-        **kwargs
+        self, plotly_name="tracerefminus", parent_name="histogram.error_x", **kwargs
     ):
         super(TracerefminusValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'style'),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "style"),
+            min=kwargs.pop("min", 0),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
