@@ -2,17 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class UirevisionValidator(_plotly_utils.basevalidators.AnyValidator):
-
     def __init__(
-        self,
-        plotly_name='uirevision',
-        parent_name='histogram2dcontour',
-        **kwargs
+        self, plotly_name="uirevision", parent_name="histogram2dcontour", **kwargs
     ):
         super(UirevisionValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'none'),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "none"),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
