@@ -2,18 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class OutlinewidthValidator(_plotly_utils.basevalidators.NumberValidator):
-
     def __init__(
-        self,
-        plotly_name='outlinewidth',
-        parent_name='isosurface.colorbar',
-        **kwargs
+        self, plotly_name="outlinewidth", parent_name="isosurface.colorbar", **kwargs
     ):
         super(OutlinewidthValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "calc"),
+            min=kwargs.pop("min", 0),
+            role=kwargs.pop("role", "style"),
             **kwargs
         )
