@@ -2,19 +2,15 @@ import _plotly_utils.basevalidators
 
 
 class DiffuseValidator(_plotly_utils.basevalidators.NumberValidator):
-
     def __init__(
-        self,
-        plotly_name='diffuse',
-        parent_name='isosurface.lighting',
-        **kwargs
+        self, plotly_name="diffuse", parent_name="isosurface.lighting", **kwargs
     ):
         super(DiffuseValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            max=kwargs.pop('max', 1),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "calc"),
+            max=kwargs.pop("max", 1),
+            min=kwargs.pop("min", 0),
+            role=kwargs.pop("role", "style"),
             **kwargs
         )
