@@ -1,15 +1,15 @@
 import _plotly_utils.basevalidators
 
 
-class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
-
-    def __init__(self, plotly_name='yaxis', parent_name='layout', **kwargs):
-        super(YAxisValidator, self).__init__(
+class YaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
+    def __init__(self, plotly_name="yaxis", parent_name="layout", **kwargs):
+        super(YaxisValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'YAxis'),
+            data_class_str=kwargs.pop("data_class_str", "YAxis"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
             anchor
                 If set to an opposite-letter axis id (e.g.
                 `x2`, `y`), this axis is bound to the
@@ -35,8 +35,8 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 appear. Only has an effect if `categoryorder`
                 is set to "array". Used with `categoryorder`.
             categoryarraysrc
-                Sets the source reference on plot.ly for
-                categoryarray .
+                Sets the source reference on Chart Studio Cloud
+                for  categoryarray .
             categoryorder
                 Specifies the ordering logic for the case of
                 categorical variables. By default, plotly uses
@@ -51,7 +51,12 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 the `categoryarray` array, the sorting behavior
                 for that attribute will be identical to the
                 "trace" mode. The unspecified categories will
-                follow the categories in `categoryarray`.
+                follow the categories in `categoryarray`. Set
+                `categoryorder` to *total ascending* or *total
+                descending* if order should be determined by
+                the numerical order of the values. Similarly,
+                the order can be determined by the min, max,
+                sum, mean or median of all the values.
             color
                 Sets default for all colors associated with
                 this axis all at once: line, font, tick, and
@@ -126,12 +131,13 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
             hoverformat
                 Sets the hover text formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see: h
-                ttps://github.com/d3/d3-format/blob/master/READ
-                ME.md#locale_format And for dates see:
-                https://github.com/d3/d3-time-
-                format/blob/master/README.md#locale_format We
-                add one item to d3's date formatter: "%{n}f"
+                similar to those in Python. For numbers, see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                And for dates see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                We add one item to d3's date formatter: "%{n}f"
                 for fractional seconds with n digits. For
                 example, *2016-10-13 09:15:23.456* with
                 tickformat "%H~%M~%S.%2f" would display
@@ -149,6 +155,16 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the axis line color.
             linewidth
                 Sets the width (in px) of the axis line.
+            matches
+                If set to another axis id (e.g. `x2`, `y`), the
+                range of this axis will match the range of the
+                corresponding axis in data-coordinates space.
+                Moreover, matching axes share auto-range
+                values, category lists and histogram auto-bins.
+                Note that setting axes simultaneously in both a
+                `scaleanchor` and a `matches` constraint is
+                currently forbidden. Moreover, note that
+                matching axes must have the same `type`.
             mirror
                 Determines if the axis lines or/and ticks are
                 mirrored to the opposite side of the plotting
@@ -188,6 +204,15 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 should be numbers, using the scale where each
                 category is assigned a serial number from zero
                 in the order it appears.
+            rangebreaks
+                A tuple of :class:`plotly.graph_objects.layout.
+                yaxis.Rangebreak` instances or dicts with
+                compatible properties
+            rangebreakdefaults
+                When used in a template (as layout.template.lay
+                out.yaxis.rangebreakdefaults), sets the default
+                property values to use for elements of
+                layout.yaxis.rangebreaks
             rangemode
                 If "normal", the range is computed in relation
                 to the extrema of the input data. If *tozero*`,
@@ -214,7 +239,9 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 {scaleanchor: *y*}` or longer) are redundant
                 and the last constraint encountered will be
                 ignored to avoid possible inconsistent
-                constraints via `scaleratio`.
+                constraints via `scaleratio`. Note that setting
+                axes simultaneously in both a `scaleanchor` and
+                a `matches` constraint is currently forbidden.
             scaleratio
                 If this axis is linked to another by
                 `scaleanchor`, this determines the pixel to
@@ -307,19 +334,21 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
             tickformat
                 Sets the tick label formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see: h
-                ttps://github.com/d3/d3-format/blob/master/READ
-                ME.md#locale_format And for dates see:
-                https://github.com/d3/d3-time-
-                format/blob/master/README.md#locale_format We
-                add one item to d3's date formatter: "%{n}f"
+                similar to those in Python. For numbers, see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                And for dates see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                We add one item to d3's date formatter: "%{n}f"
                 for fractional seconds with n digits. For
                 example, *2016-10-13 09:15:23.456* with
                 tickformat "%H~%M~%S.%2f" would display
                 "09~15~23.46"
             tickformatstops
-                plotly.graph_objs.layout.yaxis.Tickformatstop
-                instance or dict with compatible properties
+                A tuple of :class:`plotly.graph_objects.layout.
+                yaxis.Tickformatstop` instances or dicts with
+                compatible properties
             tickformatstopdefaults
                 When used in a template (as layout.template.lay
                 out.yaxis.tickformatstopdefaults), sets the
@@ -360,20 +389,20 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `tickmode` is set to "array". Used with
                 `tickvals`.
             ticktextsrc
-                Sets the source reference on plot.ly for
-                ticktext .
+                Sets the source reference on Chart Studio Cloud
+                for  ticktext .
             tickvals
                 Sets the values at which ticks on this axis
                 appear. Only has an effect if `tickmode` is set
                 to "array". Used with `ticktext`.
             tickvalssrc
-                Sets the source reference on plot.ly for
-                tickvals .
+                Sets the source reference on Chart Studio Cloud
+                for  tickvals .
             tickwidth
                 Sets the tick width (in px).
             title
-                plotly.graph_objs.layout.yaxis.Title instance
-                or dict with compatible properties
+                :class:`plotly.graph_objects.layout.yaxis.Title
+                ` instance or dict with compatible properties
             titlefont
                 Deprecated: Please use layout.yaxis.title.font
                 instead. Sets this axis' title font. Note that
@@ -402,7 +431,7 @@ class YAxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the line color of the zero line.
             zerolinewidth
                 Sets the width (in px) of the zero line.
-"""
+""",
             ),
             **kwargs
         )
