@@ -2,17 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class LinecolorValidator(_plotly_utils.basevalidators.ColorValidator):
-
     def __init__(
-        self,
-        plotly_name='linecolor',
-        parent_name='layout.scene.yaxis',
-        **kwargs
+        self, plotly_name="linecolor", parent_name="layout.scene.yaxis", **kwargs
     ):
         super(LinecolorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'plot'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "plot"),
+            role=kwargs.pop("role", "style"),
             **kwargs
         )
