@@ -2,16 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class AaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
-
-    def __init__(
-        self, plotly_name='aaxis', parent_name='layout.ternary', **kwargs
-    ):
+    def __init__(self, plotly_name="aaxis", parent_name="layout.ternary", **kwargs):
         super(AaxisValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'Aaxis'),
+            data_class_str=kwargs.pop("data_class_str", "Aaxis"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
             color
                 Sets default for all colors associated with
                 this axis all at once: line, font, tick, and
@@ -60,12 +58,13 @@ class AaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
             hoverformat
                 Sets the hover text formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see: h
-                ttps://github.com/d3/d3-format/blob/master/READ
-                ME.md#locale_format And for dates see:
-                https://github.com/d3/d3-time-
-                format/blob/master/README.md#locale_format We
-                add one item to d3's date formatter: "%{n}f"
+                similar to those in Python. For numbers, see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                And for dates see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                We add one item to d3's date formatter: "%{n}f"
                 for fractional seconds with n digits. For
                 example, *2016-10-13 09:15:23.456* with
                 tickformat "%H~%M~%S.%2f" would display
@@ -143,20 +142,21 @@ class AaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
             tickformat
                 Sets the tick label formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see: h
-                ttps://github.com/d3/d3-format/blob/master/READ
-                ME.md#locale_format And for dates see:
-                https://github.com/d3/d3-time-
-                format/blob/master/README.md#locale_format We
-                add one item to d3's date formatter: "%{n}f"
+                similar to those in Python. For numbers, see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                And for dates see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                We add one item to d3's date formatter: "%{n}f"
                 for fractional seconds with n digits. For
                 example, *2016-10-13 09:15:23.456* with
                 tickformat "%H~%M~%S.%2f" would display
                 "09~15~23.46"
             tickformatstops
-                plotly.graph_objs.layout.ternary.aaxis.Tickform
-                atstop instance or dict with compatible
-                properties
+                A tuple of :class:`plotly.graph_objects.layout.
+                ternary.aaxis.Tickformatstop` instances or
+                dicts with compatible properties
             tickformatstopdefaults
                 When used in a template (as layout.template.lay
                 out.ternary.aaxis.tickformatstopdefaults), sets
@@ -190,20 +190,21 @@ class AaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `tickmode` is set to "array". Used with
                 `tickvals`.
             ticktextsrc
-                Sets the source reference on plot.ly for
-                ticktext .
+                Sets the source reference on Chart Studio Cloud
+                for  ticktext .
             tickvals
                 Sets the values at which ticks on this axis
                 appear. Only has an effect if `tickmode` is set
                 to "array". Used with `ticktext`.
             tickvalssrc
-                Sets the source reference on plot.ly for
-                tickvals .
+                Sets the source reference on Chart Studio Cloud
+                for  tickvals .
             tickwidth
                 Sets the tick width (in px).
             title
-                plotly.graph_objs.layout.ternary.aaxis.Title
-                instance or dict with compatible properties
+                :class:`plotly.graph_objects.layout.ternary.aax
+                is.Title` instance or dict with compatible
+                properties
             titlefont
                 Deprecated: Please use
                 layout.ternary.aaxis.title.font instead. Sets
@@ -215,7 +216,7 @@ class AaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
                 axis `min`, and `title` if in `editable: true`
                 configuration. Defaults to
                 `ternary<N>.uirevision`.
-"""
+""",
             ),
             **kwargs
         )
