@@ -2,17 +2,16 @@ import _plotly_utils.basevalidators
 
 
 class TemplateitemnameValidator(_plotly_utils.basevalidators.StringValidator):
-
     def __init__(
         self,
-        plotly_name='templateitemname',
-        parent_name='layout.ternary.baxis.tickformatstop',
+        plotly_name="templateitemname",
+        parent_name="layout.ternary.baxis.tickformatstop",
         **kwargs
     ):
         super(TemplateitemnameValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'plot'),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "plot"),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
