@@ -2,18 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class TicklenValidator(_plotly_utils.basevalidators.NumberValidator):
-
     def __init__(
-        self,
-        plotly_name='ticklen',
-        parent_name='layout.ternary.caxis',
-        **kwargs
+        self, plotly_name="ticklen", parent_name="layout.ternary.caxis", **kwargs
     ):
         super(TicklenValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'plot'),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "plot"),
+            min=kwargs.pop("min", 0),
+            role=kwargs.pop("role", "style"),
             **kwargs
         )
