@@ -2,14 +2,11 @@ import _plotly_utils.basevalidators
 
 
 class TicktextsrcValidator(_plotly_utils.basevalidators.SrcValidator):
-
-    def __init__(
-        self, plotly_name='ticktextsrc', parent_name='layout.yaxis', **kwargs
-    ):
+    def __init__(self, plotly_name="ticktextsrc", parent_name="layout.yaxis", **kwargs):
         super(TicktextsrcValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'none'),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "none"),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
