@@ -2,17 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class TickprefixValidator(_plotly_utils.basevalidators.StringValidator):
-
     def __init__(
-        self,
-        plotly_name='tickprefix',
-        parent_name='scatter.marker.colorbar',
-        **kwargs
+        self, plotly_name="tickprefix", parent_name="scatter.marker.colorbar", **kwargs
     ):
         super(TickprefixValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            role=kwargs.pop("role", "style"),
             **kwargs
         )
