@@ -2,13 +2,12 @@ import _plotly_utils.basevalidators
 
 
 class SceneValidator(_plotly_utils.basevalidators.SubplotidValidator):
-
-    def __init__(self, plotly_name='scene', parent_name='scatter3d', **kwargs):
+    def __init__(self, plotly_name="scene", parent_name="scatter3d", **kwargs):
         super(SceneValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            dflt=kwargs.pop('dflt', 'scene'),
-            edit_type=kwargs.pop('edit_type', 'calc+clearAxisTypes'),
-            role=kwargs.pop('role', 'info'),
+            dflt=kwargs.pop("dflt", "scene"),
+            edit_type=kwargs.pop("edit_type", "calc+clearAxisTypes"),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
