@@ -2,18 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class TracerefValidator(_plotly_utils.basevalidators.IntegerValidator):
-
     def __init__(
-        self,
-        plotly_name='traceref',
-        parent_name='scatter3d.error_x',
-        **kwargs
+        self, plotly_name="traceref", parent_name="scatter3d.error_x", **kwargs
     ):
         super(TracerefValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "calc"),
+            min=kwargs.pop("min", 0),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
