@@ -1,17 +1,17 @@
 import _plotly_utils.basevalidators
 
 
-class ColorBarValidator(_plotly_utils.basevalidators.CompoundValidator):
-
+class ColorbarValidator(_plotly_utils.basevalidators.CompoundValidator):
     def __init__(
-        self, plotly_name='colorbar', parent_name='scatter3d.marker', **kwargs
+        self, plotly_name="colorbar", parent_name="scatter3d.marker", **kwargs
     ):
-        super(ColorBarValidator, self).__init__(
+        super(ColorbarValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            data_class_str=kwargs.pop('data_class_str', 'ColorBar'),
+            data_class_str=kwargs.pop("data_class_str", "ColorBar"),
             data_docs=kwargs.pop(
-                'data_docs', """
+                "data_docs",
+                """
             bgcolor
                 Sets the color of padded area.
             bordercolor
@@ -126,20 +126,21 @@ class ColorBarValidator(_plotly_utils.basevalidators.CompoundValidator):
             tickformat
                 Sets the tick label formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see: h
-                ttps://github.com/d3/d3-format/blob/master/READ
-                ME.md#locale_format And for dates see:
-                https://github.com/d3/d3-time-
-                format/blob/master/README.md#locale_format We
-                add one item to d3's date formatter: "%{n}f"
+                similar to those in Python. For numbers, see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Formatting.md#d3_format
+                And for dates see:
+                https://github.com/d3/d3-3.x-api-
+                reference/blob/master/Time-Formatting.md#format
+                We add one item to d3's date formatter: "%{n}f"
                 for fractional seconds with n digits. For
                 example, *2016-10-13 09:15:23.456* with
                 tickformat "%H~%M~%S.%2f" would display
                 "09~15~23.46"
             tickformatstops
-                plotly.graph_objs.scatter3d.marker.colorbar.Tic
-                kformatstop instance or dict with compatible
-                properties
+                A tuple of :class:`plotly.graph_objects.scatter
+                3d.marker.colorbar.Tickformatstop` instances or
+                dicts with compatible properties
             tickformatstopdefaults
                 When used in a template (as layout.template.dat
                 a.scatter3d.marker.colorbar.tickformatstopdefau
@@ -174,20 +175,21 @@ class ColorBarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 `tickmode` is set to "array". Used with
                 `tickvals`.
             ticktextsrc
-                Sets the source reference on plot.ly for
-                ticktext .
+                Sets the source reference on Chart Studio Cloud
+                for  ticktext .
             tickvals
                 Sets the values at which ticks on this axis
                 appear. Only has an effect if `tickmode` is set
                 to "array". Used with `ticktext`.
             tickvalssrc
-                Sets the source reference on plot.ly for
-                tickvals .
+                Sets the source reference on Chart Studio Cloud
+                for  tickvals .
             tickwidth
                 Sets the tick width (in px).
             title
-                plotly.graph_objs.scatter3d.marker.colorbar.Tit
-                le instance or dict with compatible properties
+                :class:`plotly.graph_objects.scatter3d.marker.c
+                olorbar.Title` instance or dict with compatible
+                properties
             titlefont
                 Deprecated: Please use
                 scatter3d.marker.colorbar.title.font instead.
@@ -222,7 +224,7 @@ class ColorBarValidator(_plotly_utils.basevalidators.CompoundValidator):
             ypad
                 Sets the amount of padding (in px) along the y
                 direction.
-"""
+""",
             ),
             **kwargs
         )
