@@ -2,17 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class SizerefValidator(_plotly_utils.basevalidators.NumberValidator):
-
     def __init__(
-        self,
-        plotly_name='sizeref',
-        parent_name='scattercarpet.marker',
-        **kwargs
+        self, plotly_name="sizeref", parent_name="scattercarpet.marker", **kwargs
     ):
         super(SizerefValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "calc"),
+            role=kwargs.pop("role", "style"),
             **kwargs
         )
