@@ -2,17 +2,16 @@ import _plotly_utils.basevalidators
 
 
 class TickvalssrcValidator(_plotly_utils.basevalidators.SrcValidator):
-
     def __init__(
         self,
-        plotly_name='tickvalssrc',
-        parent_name='scattercarpet.marker.colorbar',
+        plotly_name="tickvalssrc",
+        parent_name="scattercarpet.marker.colorbar",
         **kwargs
     ):
         super(TickvalssrcValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'none'),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "none"),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
