@@ -2,18 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class DashValidator(_plotly_utils.basevalidators.DashValidator):
-
-    def __init__(
-        self, plotly_name='dash', parent_name='scattergeo.line', **kwargs
-    ):
+    def __init__(self, plotly_name="dash", parent_name="scattergeo.line", **kwargs):
         super(DashValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "calc"),
+            role=kwargs.pop("role", "style"),
             values=kwargs.pop(
-                'values',
-                ['solid', 'dot', 'dash', 'longdash', 'dashdot', 'longdashdot']
+                "values", ["solid", "dot", "dash", "longdash", "dashdot", "longdashdot"]
             ),
             **kwargs
         )
