@@ -2,17 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class TickvalsValidator(_plotly_utils.basevalidators.DataArrayValidator):
-
     def __init__(
-        self,
-        plotly_name='tickvals',
-        parent_name='scattergl.marker.colorbar',
-        **kwargs
+        self, plotly_name="tickvals", parent_name="scattergl.marker.colorbar", **kwargs
     ):
         super(TickvalsValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            role=kwargs.pop('role', 'data'),
+            edit_type=kwargs.pop("edit_type", "calc"),
+            role=kwargs.pop("role", "data"),
             **kwargs
         )
