@@ -2,18 +2,14 @@ import _plotly_utils.basevalidators
 
 
 class YpadValidator(_plotly_utils.basevalidators.NumberValidator):
-
     def __init__(
-        self,
-        plotly_name='ypad',
-        parent_name='scatterpolar.marker.colorbar',
-        **kwargs
+        self, plotly_name="ypad", parent_name="scatterpolar.marker.colorbar", **kwargs
     ):
         super(YpadValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'colorbars'),
-            min=kwargs.pop('min', 0),
-            role=kwargs.pop('role', 'style'),
+            edit_type=kwargs.pop("edit_type", "colorbars"),
+            min=kwargs.pop("min", 0),
+            role=kwargs.pop("role", "style"),
             **kwargs
         )
