@@ -2,17 +2,13 @@ import _plotly_utils.basevalidators
 
 
 class ZValidator(_plotly_utils.basevalidators.BooleanValidator):
-
     def __init__(
-        self,
-        plotly_name='z',
-        parent_name='surface.contours.z.project',
-        **kwargs
+        self, plotly_name="z", parent_name="surface.contours.z.project", **kwargs
     ):
         super(ZValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
-            edit_type=kwargs.pop('edit_type', 'calc'),
-            role=kwargs.pop('role', 'info'),
+            edit_type=kwargs.pop("edit_type", "calc"),
+            role=kwargs.pop("role", "info"),
             **kwargs
         )
