@@ -9,10 +9,10 @@ gg <- ggplot(df) + geom_point(aes(x, y))
 test_that("second trace be the hline", {
   p <- gg + geom_hline(yintercept = 1.1, colour = "green", size = 3)
   
-  L <- save_outputs(p, "hline")
-  expect_equal(length(L$data), 2)
+  L <- expect_doppelganger_built(p, "hline")
+  expect_equivalent(length(L$data), 2)
   l <- L$data[[2]]
-  expect_equal(unique(l$y), 1.1)
+  expect_equivalent(unique(l$y), 1.1)
   expect_true(min(l$x) < min(x))
   expect_true(max(l$x[2]) > max(x))
   expect_identical(l$mode, "lines")
@@ -22,11 +22,11 @@ test_that("second trace be the hline", {
 test_that("vector yintercept results in multiple horizontal lines", {
   p <- gg + geom_hline(yintercept = 1:3, colour = "red", size = 3)
   
-  L <- save_outputs(p, "hline-multiple")
-  expect_equal(length(L$data), 2)
+  L <- expect_doppelganger_built(p, "hline-multiple")
+  expect_equivalent(length(L$data), 2)
   l <- L$data[[2]]
   ys <- l$y
-  expect_identical(ys, c(1, 1, NA, 2, 2, NA, 3, 3))
+  expect_equivalent(ys, c(1, 1, NA, 2, 2, NA, 3, 3))
   xs <- l$x
   expect_true(min(xs, na.rm = TRUE) < min(x))
   expect_true(max(xs, na.rm = TRUE) > max(x))
@@ -43,8 +43,8 @@ test_that("hline can be drawn over range of factors", {
   gg <- ggplot(df, aes(x = cond, y = result)) +
     geom_bar(position = "dodge", stat = "identity") +
     geom_hline(aes(yintercept = 12))
-  L <- save_outputs(gg, "hline-factor")
-  expect_equal(length(L$data), 2)  # 1 trace for bar chart, 1 trace for hline
+  L <- expect_doppelganger_built(gg, "hline-factor")
+  expect_equivalent(length(L$data), 2)  # 1 trace for bar chart, 1 trace for hline
 })
 
 
@@ -61,12 +61,12 @@ test_that("hline/vline/abline split on linetype/colour/size", {
   l <- plotly_build(gg)$x
   expect_length(l$data, 9)
   
-  expect_equal(
+  expect_equivalent(
     vapply(l$data, function(x) x$line$dash, character(1)), 
     lty2dash(c(1:3, rep(1, 6)))
   )
   
-  expect_equal(
+  expect_equivalent(
     unique(vapply(l$data, function(x) x$line$color, character(1))),
     c("rgba(0,0,0,1)", "rgba(255,0,0,1)", "rgba(0,205,0,1)")
   )
