@@ -3,14 +3,14 @@ context("geom_jitter")
 # Expect trace function
 expect_traces <- function(gg, n_traces, name) {
   stopifnot(is.numeric(n_traces))
-  save_outputs(gg, paste0("jitter-", name))
+  expect_doppelganger_built(gg, paste0("jitter-", name))
   L <- gg2list(gg)
   all_traces <- L$data
   no_data <- sapply(all_traces, function(tr) {
     is.null(tr[["x"]]) && is.null(tr[["y"]])
   })
   has_data <- all_traces[!no_data]
-  expect_equal(length(has_data), n_traces)
+  expect_equivalent(length(has_data), n_traces)
   list(traces = has_data, layout = L$layout)
 }
 
